/*============================================================================*
 * FILE:                          CEWCS388.H                                  *
 *============================================================================*
 *                                                                            *
 *      COPYRIGHT (C) 1998-2016 BY ABACO SYSTEMS, INC. 
 *      ALL RIGHTS RESERVED.
 *
 *      THIS SOFTWARE IS FURNISHED UNDER A LICENSE AND MAY BE USED AND
 *      COPIED ONLY IN ACCORDANCE WITH THE TERMS OF SUCH LICENSE AND WITH
 *      THE INCLUSION OF THE ABOVE COPYRIGHT NOTICE.  THIS SOFTWARE OR ANY
 *      OTHER COPIES THEREOF MAY NOT BE PROVIDED OR OTHERWISE MADE
 *      AVAILABLE TO ANY OTHER PERSON.  NO TITLE TO AND OWNERSHIP OF THE
 *      SOFTWARE IS HEREBY TRANSFERRED.
 *
 *      THE INFORMATION IN THIS SOFTWARE IS SUBJECT TO CHANGE WITHOUT
 *      NOTICE AND SHOULD NOT BE CONSTRUED AS A COMMITMENT BY ABACO SYSTEMS.
 *                                      *
 *                                                                            *
 *============================================================================*
 *                                                                            *
 * FUNCTION:   BusTools API library: This file contains the                   *
 *             PCI-/PMC-/ISA-1553 down loadable firmware.                     *
 *                                                                            *
 *             These 16-bit values must be loaded into the WCS area of the    *
 *             board, per the hardware reference manual, before the micro-    *
 *             code is started and normal operations can begin.               *
 *                                                                            *
 *===========================================================================*/

/* $Revision:  3.88 Release $ 
   $Date    :  Wed Mar 31 16:33:36 2004
   ----------------------------------------------------------------------------
   Revision 3.08 (12/07/2000) Release
   - Improved the decoder.
   - Added support for broadcast and normal messages with intermessage gaps down
     to 4 microseconds.
   
   Revision 3.06 (3-30-2000)
   -Modified code to fix Transmit Last Command Word mode code bug. The current
    command would get written into the TLCW buffer and sent instead. 3/30/00 (~noon)
    Added Last Command and BIT words saved in RT Message Buffer 3/30/00 (4:30pm).
   
   Revision 3.05 (3-27-2000)
   -Fixed BCR bit bug for broadcast rt-rt (it is actually a broadcast bug).
    Created new file register, rtctlpts (0x34) to copy rtctlptr (0x48) contents
    over before they get updated for next message. rtctlpts is used in procbcst
    to update the bcr bits for the RTs. 3/27/00 (5:30pm)
   
   Revision 3.04 (3-23-2000)
   -Mode Code status word was not being placed into the RT message buffer.
   
   Revision 3.03 (2-21-2000)
   -This version adds BM interrupt trigger enable to control BM trigger output
    on every message.  LPU V3.03 fixes the interrupt queue message skip problem.
   
   Revision 3.02 (12-15-1999)(12-22-1999)
   - Adds time tag load interrupt.
   - Minor playback firmware problem fixed.
   - Version ID added to the firmware load at offset 2.
   
   Revision 3.01 (11-29-1999)
   - Fixes Broadcast RT-RT no response problem.
   - BM triggers external TTL output problem resolved.
   
   Revision 3.00 (11-5-1999) supports 45-bit time tags, HW interrupts and Playback
   - Reduced 45-bit time tag timer.
   - HW interrupts
   - Playback
   
   Revision 2.55 (6/9/99) supports 48-bit time tags and HW interrupts
   - New enhanced 48-bit tag timer.
   - PCI interrupt capability.
   - BC busy bit may no longer be written to by host.
   - External input works with version 2.54 and 2.55 (fix bug of versions 2.50 & 2.51).
   
   List of known bugs with Revision 2.55:
   
   - Errors are reported on an unterminated bus that do not indicate the source of
     the problem.
   - For single mode boards, attempting to turn on more than one mode (BC, RT, BM)
     bit at a time will cause all three bits to turn off. This might produce bus
     errors if the BC is turned off mid-message.
   - The user needs to be aware of allowing sufficient intermessage gap time for
     both paths of conditional sequence following a broadcast command.
   - Trigger on data needs to be linked to a command.
   - Response on wrong bus detection reports "No Response" rather than "Wrong Bus".
   - Broadcast commands with low word error only set message error in a single RT's
     status word.
   - Mode Codes with low word errors might not interrupt the processor (untested).
   - Reserved transmit mode codes are illegal, but the message error bit is not set
     when they are received.
   - Reserved broadcast transmit mode code with data word commands are treated as
     invalid rather than illegal. This means that we will not monitor (BM) or set
     the message error bit in the status word (RT) for these reserved mode commands.
   - Switching channels on rt-rt messages can cause no response for receiving RT
     when it is external from the simulated BC and simulated transmitting RT.
   - Dynamic Bus Control and Selected/Override selected Transmitter mode commands
     have bugs.
   - Low output voltage (PCI/ISA-1553) may be a problem for long cable lengths.
   - High bit count errors don't behave correctly. Depending on the message format
     and word they are injected into, they are monitored as "no error", "no message",
     "low word" or parity error. It is consistent and never affects messages before
     or after the message with the high bit count injection.
   - Injecting errors into command words causes the "Bus Termination" message to
     occur once on BusTools. This is not a problem when running the DOS-based
     MDPRO32. Injecting errors into receive command word of RT to RT message
     causes only the BC to see an interrupt.
   - Error Inject low bit count in mode command. Terminal flag bit in status word
     set in BusTools error dialogue.
   - Broadcast Mode Code: Sync w/o data word is programmed in BusTools but doesn't
     seem to get transmitted. It looks OK in MDPRO32.
   - RT message buffer can catch up to software over the long haul. Need a better
     handshaking method.
   
   Revision 2.50 (12/98) is the initial PCI-1553 firmware release.
   
   List of known bugs with Revision 2.50:
   - Errors are reported on an unterminated bus that do not indicate the source of
     the problem.
   - For single mode boards, attempting to turn on more than one mode (BC, RT, BM)
     bit at a time will cause all three bits to turn off. This might produce bus
     errors if the BC is turned off mid-message.
   - The user needs to be aware of allowing sufficient intermessage gap time for
     both paths of conditional sequence following a broadcast command.
   - Trigger on data needs to be linked to a command.
   - Response on wrong bus detection reports "No Response" rather than "Wrong Bus".
   - Broadcast commands with low word error only set message error in a single
     RT's status word.
   - Mode Codes with low word errors might not interrupt the processor (untested).
   - Reserved transmit mode codes are illegal, but the message error bit is not
     set when they are received.
   - Reserved broadcast transmit mode code with data word commands are treated as
     invalid rather than illegal. This means that we will not monitor (BM) or set
     the message error bit in the status word (RT) for these reserved mode
     commands.
   - Switching channels on rt-rt messages can cause no response for receiving RT
     when it is external from the simulated BC and simulated transmitting RT.
   - Dynamic Bus Control and Selected/Override selected Transmitter mode commands
     have bugs.
                                                                             */

0xFFFF, 0x001F, 0x5FFF, 0xFFFF, 0x001F, 0x5FFF, 0x0006, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0303, 0x0303, 0x0303, 0x8888, 0x8888, 0x8888, 
0x1388, 0x001F, 0x5FCA, 0xFFFF, 0xE01F, 0x6CF6, 0xFFFF, 0xE11F, 0x6CF6, 
0xFFFF, 0x001F, 0x5FD1, 0xFFFF, 0x001F, 0x40F3, 0xFFFF, 0x001F, 0x5FF8, 
0xFFFF, 0x0000, 0x5F3F, 0xFFFF, 0x00FF, 0x5FFF, 0x001E, 0x003F, 0x5FFF, 
0x0066, 0xF83F, 0x6CC0, 0x001E, 0x003F, 0x5FFF, 0x0066, 0xF83F, 0x6CC0, 
0x001E, 0x003F, 0x5FFF, 0x0066, 0xF83F, 0x6CC0, 0x001E, 0x003F, 0x5FFF, 
0x0066, 0xF83F, 0x6CC0, 0x001E, 0x003F, 0x5FFF, 0x0031, 0x003F, 0x5FFF, 
0x001E, 0x003F, 0x5FFF, 0x0031, 0x003F, 0x5FFF, 0x001E, 0x003F, 0x5FFF, 
0x0031, 0x003F, 0x5FFF, 0x001E, 0x003F, 0x5FFF, 0x0031, 0x003F, 0x5FFF, 
0xFFFF, 0xA310, 0x6CFF, 0x0909, 0x00CD, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x000C, 0x003F, 0x5FFF, 0x0A47, 0x003F, 0x5FFF, 0x0872, 0x003F, 0x5FFF, 
0x0872, 0x003F, 0x5FFF, 0x01A8, 0x003F, 0x40F3, 0x01A8, 0x003F, 0x40F3, 
0x01A8, 0x003F, 0x40F3, 0x01A8, 0x003F, 0x40F3, 0x0901, 0x003F, 0x4BC0, 
0x0901, 0x003F, 0x4BC0, 0x0872, 0x003F, 0x5FFF, 0x0872, 0x003F, 0x5FFF, 
0x01A8, 0x003F, 0x40F3, 0x01A8, 0x003F, 0x40F3, 0x01A8, 0x003F, 0x40F3, 
0x01A8, 0x003F, 0x40F3, 0xFFFF, 0x001F, 0x4BE2, 0xFFFF, 0xE51F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x0182, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x5FFA, 
0xFFFF, 0x001F, 0x5FD1, 0xFFFF, 0x001F, 0x40F3, 0xFFFF, 0x001F, 0x5FE9, 
0xFFFF, 0x001F, 0x5FF7, 0xFF80, 0x001F, 0x5CE2, 0xFFFF, 0xF81F, 0x6CCB, 
0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xDA1F, 0x2AFF, 
0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xAE1F, 0x2AFF, 0xFFFF, 0xB81F, 0x6CE2, 
0xFFFF, 0xAF1F, 0x2AFF, 0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xB01F, 0x2AFF, 
0xFFFF, 0xD81F, 0x6CC6, 0xFFFF, 0xBA1F, 0x28FF, 0xFFFF, 0xAA1F, 0x6CE2, 
0xFFFF, 0x0007, 0x5FFF, 0x0053, 0x00DF, 0x5FFF, 0xFFFF, 0xC11F, 0x6CE2, 
0xFFFF, 0xAC1F, 0x2AFF, 0xFFFF, 0xAA1F, 0x6CE2, 0xFFFF, 0xC11F, 0x2AFF, 
0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xAE1F, 0x2AFF, 0xFFFF, 0x001F, 0x5FF7, 
0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xB01F, 0x2AFF, 0xFFFF, 0xC11F, 0x6CC6, 
0xFFFF, 0x0010, 0xCCC0, 0xFFFF, 0x00FF, 0x5FFF, 0x0165, 0xF83F, 0x6CE2, 
0x0165, 0xF83F, 0x6CE2, 0x0165, 0xF83F, 0x6CE2, 0x00B6, 0x003F, 0xCC13, 
0x0165, 0xF83F, 0x6CE2, 0x016F, 0xF83F, 0x6CE2, 0x0165, 0xF83F, 0x6CE2, 
0x0145, 0xF83F, 0x6CE2, 0x0165, 0xF83F, 0x6CE2, 0x0165, 0xF83F, 0x6CE2, 
0x0165, 0xF83F, 0x6CE2, 0x00B6, 0x003F, 0xCC13, 0x0165, 0xF83F, 0x6CE2, 
0x016F, 0xF83F, 0x6CE2, 0x0165, 0xF83F, 0x6CE2, 0x0145, 0xF83F, 0x6CE2, 
0xFFFF, 0xE10B, 0x6CE3, 0x01A7, 0x0047, 0x5FFF, 0x0128, 0xAA4E, 0x6CE2, 
0x01A7, 0xC1C7, 0x6CC6, 0x006C, 0xAED0, 0x6CFF, 0x009A, 0x005F, 0x5FFF, 
0xFFFF, 0x0010, 0xCCC0, 0xFFFF, 0x00FF, 0x5FFF, 0x0165, 0xF83F, 0x6CE2, 
0x0165, 0xF83F, 0x6CE2, 0x0165, 0xF83F, 0x6CE2, 0x00A4, 0x003F, 0x5FFF, 
0x0165, 0xF83F, 0x6CE2, 0x016F, 0xF83F, 0x6CE2, 0x0165, 0xF83F, 0x6CE2, 
0x0145, 0xF83F, 0x6CE2, 0x007E, 0xB030, 0x6CFF, 0x007E, 0xB030, 0x6CFF, 
0x007E, 0xB030, 0x6CFF, 0x0087, 0xB030, 0x6CFF, 0x007E, 0xB030, 0x6CFF, 
0x0081, 0xB030, 0x6CFF, 0x007E, 0xB030, 0x6CFF, 0x0084, 0xB030, 0x6CFF, 
0x008A, 0xB85F, 0x6CE2, 0xFFFF, 0xB01F, 0x2AFF, 0x0165, 0xF83F, 0x6CE2, 
0x008A, 0xB85F, 0x6CE2, 0xFFFF, 0xB01F, 0x2AFF, 0x016F, 0xF83F, 0x6CE2, 
0x008A, 0xB85F, 0x6CE2, 0xFFFF, 0xB01F, 0x2AFF, 0x0145, 0xF83F, 0x6CE2, 
0x00A2, 0xEBDF, 0x6CE3, 0xFFFF, 0x0007, 0x5FFF, 0x00A4, 0x005F, 0x5FFF, 
0xFFFF, 0xAB1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 0x01A7, 0xAFD0, 0x6CFF, 
0x01A7, 0x00DF, 0x5FFF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE51F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x01A7, 0x005F, 0x5FFF, 0xFFFF, 0xC11F, 0x6CE2, 
0xFFFF, 0xAD1F, 0x2AFF, 0xFFFF, 0xAB1F, 0x6CE2, 0xFFFF, 0xC11F, 0x2AFF, 
0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xAF1F, 0x2AFF, 0xFFFF, 0x001F, 0x5FF7, 
0x006C, 0xC13F, 0x6CC6, 0xFFFF, 0xC11F, 0x6CE2, 0xFFFF, 0xAC1F, 0x2AFF, 
0xFFFF, 0xAA1F, 0x6CE2, 0xFFFF, 0xC11F, 0x2AFF, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xAE1F, 0x2AFF, 0xFFFF, 0x001F, 0x5FF7, 0x006C, 0xC13F, 0x6CC6, 
0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xB01F, 0x2AFF, 0xFFFF, 0xE91F, 0x6C23, 
0xFFFF, 0x0007, 0xCC14, 0x00A8, 0x00DF, 0x49E0, 0xFFFF, 0xE81F, 0x6CE5, 
0xFFFF, 0x001F, 0x4AD3, 0xFFFF, 0x001F, 0x5FFF, 0xFFFF, 0x001F, 0x5FFF, 
0xFFFF, 0x000A, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x00B1, 0x003F, 0x5FF8, 
0x00B1, 0x003F, 0x5FF8, 0x00B7, 0x003F, 0x5FF7, 0x00B1, 0x003F, 0x5FF8, 
0xFFFF, 0xAE10, 0x6CFF, 0x017E, 0x00DF, 0x5FFF, 0xFFFF, 0xAF10, 0x6CFF, 
0x0120, 0x00DF, 0x5FFF, 0x0196, 0x003F, 0x5FFF, 0xFFFF, 0x001F, 0xCC14, 
0xFFFF, 0xC01F, 0x283F, 0xFFFF, 0xEB1F, 0x6CE3, 0xFFFF, 0x0007, 0x5FFF, 
0x00BF, 0x00DF, 0x5FFF, 0xF5FF, 0x001F, 0x5CE3, 0xFFFF, 0xC11F, 0x6CC6, 
0xFFFF, 0x001F, 0x8AF2, 0x00C0, 0xE33F, 0x6CD0, 0xFFFF, 0x001F, 0xCCD0, 
0xFFFF, 0xC01F, 0x6CC7, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xFB1F, 0x28FF, 
0x00C4, 0x003F, 0xCCD2, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0x8D1F, 0x29FF, 
0xFFFF, 0xEA1F, 0x6CE3, 0xFFFF, 0xC107, 0x6CC6, 0x00DA, 0xBE43, 0x6C23, 
0xFFFF, 0x00FF, 0xCCC0, 0x00DA, 0xBD3F, 0x6CE3, 0x00DA, 0xBD3F, 0x6CE3, 
0x00DA, 0xE03F, 0x6CE2, 0x00DA, 0xE03F, 0x6CE2, 0x00DA, 0xBD3F, 0x6CE3, 
0x00DA, 0xBD3F, 0x6CE3, 0x00DA, 0xE03F, 0x6CE2, 0x00DA, 0xE03F, 0x6CE2, 
0x00DA, 0xBD3F, 0x6CE3, 0x00DA, 0xBD3F, 0x6CE3, 0x00DA, 0xE03F, 0x6CE2, 
0x00DA, 0xE03F, 0x6CE2, 0x00DA, 0xBD3F, 0x6CE3, 0x00DA, 0xBD3F, 0x6CE3, 
0x00DA, 0xE03F, 0x6CE2, 0x00DA, 0xE03F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 
0x00DE, 0xCE5F, 0x2AFF, 0xFFFF, 0xE51F, 0x6CE2, 0xFFFF, 0xCE1F, 0x2AFF, 
0xFFFF, 0xC11F, 0x6CC6, 0xFFFF, 0xC61F, 0x28FF, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xFA1F, 0x29FF, 0xFFFF, 0xC01F, 0x6CC7, 0xFFFF, 0xFA1F, 0x6C00, 
0xFFFF, 0xE61F, 0x6C23, 0xFFFF, 0x0007, 0xCC35, 0x00E8, 0x00DF, 0x5FFF, 
0x00EA, 0xC23F, 0x293F, 0xFFFF, 0x001F, 0xCCF5, 0xFFFF, 0xC21F, 0x293F, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0xC01F, 0x283F, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x8D1F, 0x6C00, 0x0040, 0x001F, 0x5C25, 0x0041, 0x0007, 0x5CE5, 
0x010B, 0x00C7, 0x5FFF, 0x010B, 0x00DF, 0x5FFF, 0xC00F, 0x001F, 0x5CE5, 
0xC00E, 0x0007, 0x5CE5, 0x010B, 0x00C7, 0x5FFF, 0x010B, 0x00DF, 0x5FFF, 
0x2000, 0x001F, 0x5CE5, 0xFFFF, 0x0007, 0x5FFF, 0x010B, 0x00DF, 0x5FFF, 
0xFFFF, 0x0003, 0xCCE2, 0xFFFF, 0xC1FF, 0x2AFF, 0x010E, 0x003F, 0x5FE8, 
0x010E, 0x003F, 0x5FE8, 0x0111, 0x003F, 0x5FE8, 0x010E, 0x003F, 0x5FE8, 
0x0111, 0x003F, 0x5FE8, 0x0111, 0x003F, 0x5FE8, 0x0111, 0x003F, 0x5FE8, 
0x0111, 0x003F, 0x5FE8, 0x010E, 0x003F, 0x5FE8, 0x010E, 0x003F, 0x5FE8, 
0x0111, 0x003F, 0x5FE8, 0x010E, 0x003F, 0x5FE8, 0x0111, 0x003F, 0x5FE8, 
0x0111, 0x003F, 0x5FE8, 0x0111, 0x003F, 0x5FE8, 0x0111, 0x003F, 0x5FE8, 
0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xC11F, 0x2AFF, 0x0111, 0x003F, 0x5FFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE11F, 0x6CCC, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF61F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xC11F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 0x01A7, 0xAE50, 0x6CFF, 
0x0120, 0x005F, 0x5FFF, 0xFFFF, 0xC11F, 0x6CE2, 0xFFFF, 0xAA1F, 0x2AFF, 
0xFFFF, 0xAC1F, 0x6CE2, 0xFFFF, 0xC11F, 0x2AFF, 0xFFFF, 0xB81F, 0x6CE2, 
0xFFFF, 0xAE1F, 0x2AFF, 0xFFFF, 0x001F, 0x5FF8, 0x01A7, 0x003F, 0x5FFF, 
0xFFFF, 0xC11F, 0x6CE2, 0xFFFF, 0xAB1F, 0x2AFF, 0xFFFF, 0xAD1F, 0x6CE2, 
0xFFFF, 0xC11F, 0x2AFF, 0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xAF1F, 0x2AFF, 
0xFFFF, 0x001F, 0x5FF8, 0x01A7, 0x003F, 0x5FFF, 0xFFFF, 0xFA1F, 0x6CC0, 
0xFFFF, 0xE51F, 0x6CE3, 0xFFFF, 0xC007, 0x6CC7, 0x0134, 0x00DF, 0x5F7F, 
0xFFFF, 0x001F, 0xCCD5, 0xFFFF, 0xFB1F, 0x6CC7, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x001F, 0xCCD2, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE61F, 0x6CCC, 
0xFFFF, 0xF81F, 0x2AFF, 0x0141, 0x003F, 0x5FFF, 0xFFFF, 0xC21F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC16, 0xFFFF, 0xC21F, 0x28FF, 0xFFFF, 0xFB1F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0xFB1F, 0x28FF, 0xFFFF, 0x001F, 0xCCD2, 
0xFFFF, 0xCE1F, 0x6CC7, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xCE1F, 0x28FF, 
0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0xCE07, 0x28FF, 0x01A7, 0x005F, 0x5FFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF11F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 
0x01A7, 0x003F, 0x5FFF, 0xFFFF, 0xE51F, 0x6CCB, 0xFFFF, 0xE707, 0x6CE2, 
0x01A7, 0x005F, 0xCC0B, 0xFFFF, 0x0007, 0x5FFF, 0x014B, 0x00DF, 0x5FFF, 
0xFFFF, 0x001F, 0x5FF8, 0xFFFF, 0x001F, 0xCC35, 0xFFFF, 0x001F, 0xCC24, 
0xFFFF, 0x001F, 0xCC00, 0xFFFF, 0xFF1F, 0x28FF, 0xFFFF, 0xA71F, 0x2AFF, 
0xFFFF, 0xA71F, 0x6CC7, 0xFFFF, 0x001F, 0xCCE5, 0xFFFF, 0xFF1F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC0B, 0xFFFF, 0x0007, 0xCC00, 0x015B, 0xFF5F, 0x28FF, 
0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0x0007, 0x5FFF, 0x015C, 0x005F, 0x5FFF, 
0xFFFF, 0x001F, 0x89FF, 0x0161, 0xFF3F, 0x6CC7, 0x0161, 0x003F, 0x5F3F, 
0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0x48E2, 
0xFFFF, 0xFF1F, 0x6CC7, 0xFFFF, 0x001F, 0x8A32, 0x0004, 0x001F, 0x5CC0, 
0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0x001F, 0xCCC0, 0x0111, 0xC13F, 0x29FF, 
0xFFFF, 0xE51F, 0x6CCB, 0xFFFF, 0xE707, 0x6CE2, 0x01A7, 0x005F, 0xCC0B, 
0xFFFF, 0x0007, 0x5F3F, 0x016B, 0x00DF, 0x5F3F, 0xFFFF, 0x001F, 0x5FF8, 
0x0008, 0x001F, 0x5CC0, 0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0x001F, 0xCCC0, 
0x0111, 0xC13F, 0x29FF, 0xFFFF, 0xE51F, 0x6C0B, 0xFFFF, 0x0007, 0x5F3F, 
0x01A7, 0x005F, 0x5F3F, 0xFFFF, 0xBD1F, 0x6CE2, 0xFFFF, 0x001F, 0x5FC9, 
0xFFFF, 0xF81F, 0x6CCB, 0xFFFF, 0xF51F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xE01F, 0x6CE2, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0x001F, 0x5FFA, 
0xFFFF, 0x001F, 0x5FD1, 0xFFFF, 0x001F, 0x40F3, 0xFFFF, 0x001F, 0x5FF8, 
0x016B, 0x003F, 0x5FFC, 0xFFFF, 0xDB1F, 0x6CE2, 0xFFFF, 0xEF1F, 0x6CCC, 
0xFFFF, 0xDB1F, 0x2AFF, 0x0118, 0x003F, 0x5FFF, 0xFFFF, 0xDB1F, 0x6CE2, 
0xFFFF, 0xED1F, 0x6CCC, 0xFFFF, 0xDB1F, 0x2AFF, 0xFFFF, 0xDB1F, 0x6CE2, 
0xFFFF, 0xEA1F, 0x6CCC, 0xFFFF, 0xDB1F, 0x2AFF, 0xFFFF, 0xC11F, 0x6CC6, 
0x000B, 0x001F, 0x5CC0, 0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xC11F, 0x29FF, 0xFFFF, 0x000A, 0x5FFF, 0x0194, 0x00DF, 0x5FFF, 
0xFFFF, 0xC11F, 0x6CC6, 0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xE31F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x0188, 0x00DF, 0x5FFF, 0xFFFF, 0x001F, 0x5FF8, 
0x003A, 0x003F, 0x5FFF, 0xFFFF, 0xDB1F, 0x6CE2, 0xFFFF, 0xEA1F, 0x6CCC, 
0xFFFF, 0xDB1F, 0x2AFF, 0xFFFF, 0xC11F, 0x6CC6, 0x000B, 0x001F, 0x5CC0, 
0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xC11F, 0x29FF, 
0xFFFF, 0x000A, 0x5FFF, 0x01A5, 0x00DF, 0x5FFF, 0xFFFF, 0xC11F, 0x6CC6, 
0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xE31F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x0199, 0x00DF, 0x5FFF, 0xFFFF, 0x001F, 0x5FF8, 0x01A7, 0x003F, 0x5FFF, 
0x001E, 0x003F, 0x5FFF, 0xFFFF, 0xFC12, 0x21FF, 0xFFFF, 0xFDFF, 0x22FF, 
0x01BB, 0xD93F, 0x23FF, 0x01BA, 0x003F, 0x5FFF, 0x0575, 0x003F, 0x43C0, 
0x01BA, 0x003F, 0x5FFF, 0x06DE, 0x003F, 0x43C0, 0x01BA, 0x003F, 0x5FFF, 
0x01BA, 0x003F, 0x5FFF, 0x04CC, 0x003F, 0x43C0, 0x01BB, 0x003F, 0x43C0, 
0x01BA, 0x003F, 0x5FFF, 0x0575, 0x003F, 0x43C0, 0x0680, 0x003F, 0x43C0, 
0x06DE, 0x003F, 0x43C0, 0x01BA, 0x003F, 0x5FFF, 0x01BA, 0x003F, 0x5FFF, 
0x04CC, 0x003F, 0x43C0, 0x000C, 0x003F, 0x5FFF, 0xFFFF, 0xB41F, 0x6CFF, 
0xFFFF, 0xB51F, 0x6CFF, 0xFFFF, 0xB61F, 0x6CFF, 0xFFFF, 0xB71F, 0x6CFF, 
0xFFFF, 0xFD15, 0x6CD8, 0x046D, 0xD5DF, 0x6CC0, 0xFFFF, 0xFC13, 0x6CFF, 
0xFFFF, 0xFDFF, 0x6CC3, 0x041B, 0x003F, 0xCCC4, 0x041B, 0x003F, 0xCCC4, 
0x0459, 0x003F, 0x5FFF, 0x0414, 0x003F, 0xCCC4, 0x02DF, 0x003F, 0xCCC4, 
0x02DF, 0x003F, 0xCCC4, 0x029F, 0x003F, 0xCCC4, 0x02B6, 0x003F, 0xCCC4, 
0x01D3, 0x003F, 0xCCC4, 0x01D3, 0x003F, 0xCCC4, 0x0465, 0x003F, 0x5FFF, 
0x01D3, 0x003F, 0xCCC4, 0x046D, 0x003F, 0x5FFF, 0x046D, 0x003F, 0x5FFF, 
0x01D3, 0x003F, 0xCCC4, 0x046D, 0x003F, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xE101, 0x6CCC, 0x0263, 0xDA5F, 0x2AFF, 0xFFFF, 0xC81F, 0x283F, 
0xFFFF, 0x001F, 0xCC2E, 0xFFFF, 0x0009, 0xCC2D, 0x01DB, 0x00C9, 0xCC2E, 
0x01D9, 0x0049, 0xCC2D, 0xFFFF, 0x001F, 0x41E2, 0xFFFF, 0xEB1F, 0x6CCB, 
0xFFFF, 0xFD07, 0x6CE2, 0x029B, 0xA65F, 0x2AFF, 0xFFFF, 0xD41F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F27, 0xFFFF, 0xE01F, 0x6C99, 0xFFFF, 0x001F, 0xCCE6, 
0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0x0009, 0xCCE6, 0x01E4, 0x005F, 0x8A32, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xFC13, 0x6CFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x0287, 0x003F, 0x5FFF, 
0x0287, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x01F9, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x0209, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE51F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xDC1F, 0x6CEE, 0xFFFF, 0xDD1F, 0x6CEF, 
0xFFFF, 0xFD04, 0x6CC0, 0x0459, 0xBD5F, 0x6CE3, 0x0011, 0x001F, 0x5CCD, 
0xFFFF, 0xDB07, 0x6CC0, 0x029B, 0xE45F, 0x6CE3, 0xFFFF, 0xE607, 0x6CE3, 
0x0207, 0x0047, 0x5FFF, 0x029B, 0x00DF, 0x5FFF, 0x0208, 0x003F, 0x5FFF, 
0x029B, 0x00DF, 0x5FEA, 0x029B, 0x003F, 0x5FFE, 0xFFFF, 0x001F, 0x42FF, 
0xFFFF, 0x0010, 0x43E2, 0x0212, 0x005F, 0x5FFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xE01F, 0x6CCC, 0xFFFF, 0xD91F, 0x2AFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xFD10, 0x6CFF, 
0xFFFF, 0x00FF, 0x5FE9, 0x046D, 0x003F, 0x5FFF, 0x0224, 0x003F, 0x5FFF, 
0x046D, 0x003F, 0x5FFF, 0x022C, 0x003F, 0x5FFF, 0x0230, 0xD93F, 0x6CE2, 
0x023D, 0xD93F, 0x6CE2, 0x024C, 0xD43F, 0x6CC0, 0x0253, 0xD43F, 0x6CC0, 
0x025A, 0x003F, 0x5FFF, 0x025D, 0x003F, 0x5FFF, 0x025D, 0x003F, 0x5FFF, 
0x025D, 0x003F, 0x5FFF, 0x025D, 0x003F, 0x5FFF, 0x025D, 0x003F, 0x5FFF, 
0x025D, 0x003F, 0x5FFF, 0x025D, 0x003F, 0x5FFF, 0xFFFF, 0xDB1F, 0x6CC0, 
0xFFFF, 0xE41F, 0x6CE3, 0xFFFF, 0xE607, 0x6CE3, 0x022A, 0x0047, 0x5FFF, 
0x025D, 0x00DF, 0x5FFF, 0x022B, 0x003F, 0x5FFF, 0x025D, 0x00DF, 0x5FEA, 
0x025D, 0x003F, 0x5FFE, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE41F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0x025D, 0x003F, 0x5FFF, 0xFFFF, 0xEB1F, 0x6CCB, 
0xFFFF, 0x0007, 0x52E2, 0x0238, 0x005F, 0x5FFF, 0xFFFF, 0xB61F, 0x6CCC, 
0xFFFF, 0xB61F, 0x2AFF, 0xFFFF, 0x001F, 0x53E2, 0xFFFF, 0xB71F, 0x6CCC, 
0x025D, 0xB73F, 0x2AFF, 0xFFFF, 0xB41F, 0x6CCC, 0xFFFF, 0xB41F, 0x2AFF, 
0xFFFF, 0x001F, 0x53E2, 0xFFFF, 0xB51F, 0x6CCC, 0x025D, 0xB53F, 0x2AFF, 
0xFFFF, 0xEB1F, 0x6CCB, 0xFFFF, 0x0007, 0x52E2, 0x0246, 0x005F, 0x5FC9, 
0xFFFF, 0xB61F, 0x6CCB, 0xFFFF, 0xB61F, 0x2AFF, 0xFFFF, 0x001F, 0x53E2, 
0xFFFF, 0x001F, 0x5FC9, 0xFFFF, 0xB71F, 0x6CCB, 0x025D, 0xB73F, 0x2AFF, 
0xFFFF, 0xB41F, 0x6CCB, 0xFFFF, 0xB41F, 0x2AFF, 0xFFFF, 0x001F, 0x53E2, 
0xFFFF, 0x001F, 0x5FC9, 0xFFFF, 0xB51F, 0x6CCB, 0x025D, 0xB53F, 0x2AFF, 
0xFFFF, 0xD41F, 0x6CC7, 0xFFFF, 0x001F, 0x5FE7, 0xFFFF, 0xE11F, 0x6C99, 
0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0x0009, 0x51CC, 0x024F, 0x005F, 0x8A32, 
0x025D, 0x003F, 0x5F7F, 0xFFFF, 0xD41F, 0x6CC7, 0xFFFF, 0x001F, 0x5FE7, 
0xFFFF, 0xE21F, 0x6C99, 0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0x0009, 0x51CB, 
0x0256, 0x005F, 0x8A32, 0x025D, 0x003F, 0x5F7F, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xE31F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xE51F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xA31F, 0x2AFF, 0x029B, 0x003F, 0x5FFF, 0xFFFF, 0xFC1F, 0x6CC0, 
0xFFFF, 0xED1F, 0x6CE3, 0xFFFF, 0xEC07, 0x6CE3, 0x029E, 0x00C7, 0x5FFF, 
0x026C, 0x00DF, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE51F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0x029E, 0x003F, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xE51F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xA31F, 0x2AFF, 0xFFFF, 0x000C, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x0271, 0x003F, 0x5FFF, 0x0271, 0x003F, 0x5FFF, 0x0271, 0x003F, 0x5FFF, 
0x0271, 0x003F, 0x5FFF, 0x0281, 0x003F, 0x5FFF, 0x0281, 0x003F, 0x5FFF, 
0x027B, 0x003F, 0x5FFF, 0x027B, 0x003F, 0x5FFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xE01F, 0x6CCC, 0xFFFF, 0xD91F, 0x2AFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xFD1F, 0x6CC0, 
0xFFFF, 0xBD1F, 0x6CE3, 0xFFFF, 0xE107, 0x6CCD, 0x046D, 0x00C7, 0x5FFF, 
0x046D, 0x00DF, 0x5FE9, 0x029C, 0x003F, 0x5FFF, 0xFFFF, 0xF800, 0x6CC0, 
0x0443, 0xE14B, 0x6CE3, 0x029B, 0x0047, 0x5FFF, 0x029B, 0x00DF, 0x5FFF, 
0xFFFF, 0xC21F, 0x6CC7, 0xFFFF, 0x001F, 0xCC16, 0xFFFF, 0xC21F, 0x28FF, 
0xFFFF, 0xFB1F, 0x6CC7, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0xFB1F, 0x28FF, 
0xFFFF, 0x001F, 0xCCD2, 0xFFFF, 0xCE1F, 0x6CC7, 0xFFFF, 0x001F, 0x5F7F, 
0xFFFF, 0xCE1F, 0x28FF, 0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0xCE07, 0x28FF, 
0x029B, 0x005F, 0x5FFF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF11F, 0x6CCB, 
0xFFFF, 0xF81F, 0x2AFF, 0x0443, 0x003F, 0x5FFF, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xA31F, 0x2AFF, 0x0480, 0x003F, 0x5FFF, 0xFFFF, 0xFD1F, 0x6CE2, 
0xFFFF, 0xBD1F, 0x6CCB, 0xFFFF, 0xE107, 0x6CCD, 0x02A5, 0x00C7, 0x5FFF, 
0x02DF, 0x005F, 0x5FFF, 0x02BC, 0x003F, 0x5FFF, 0xFFFF, 0x0006, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 
0x0408, 0x003F, 0x5FFF, 0x02AF, 0x003F, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 
0x0408, 0x003F, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 0x02AF, 0x003F, 0x5FFF, 
0xFFFF, 0xFF1F, 0x28FF, 0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xFD1F, 0x6CC2, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xE31F, 0x6CE4, 0xFFFF, 0x001F, 0x8AF2, 
0x02E9, 0xFF3F, 0x6CC7, 0xFFFF, 0xDE1F, 0x6CEE, 0xFFFF, 0xDF1F, 0x6CEF, 
0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xE604, 0x6CCB, 0x0459, 0x0047, 0x5FFF, 
0x02DF, 0x00DF, 0x5FFF, 0xFFFF, 0x001F, 0xCC2E, 0xFFFF, 0x001F, 0xCC2F, 
0xFFFF, 0xC804, 0x28FF, 0x02C1, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x5FDA, 
0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0x001F, 0x48C1, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xD01F, 0x28FF, 0xFFFF, 0xD406, 0x6CC0, 
0xFFFF, 0xFDFF, 0x6CC2, 0x0408, 0x003F, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 
0x0408, 0x003F, 0x5FFF, 0x02F3, 0x003F, 0xCC00, 0x0408, 0x003F, 0x5FFF, 
0x0408, 0x003F, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 0x02D0, 0x003F, 0xCC00, 
0xFFFF, 0xE01F, 0x6CE3, 0xFFFF, 0xE207, 0x6CE3, 0x0349, 0x0047, 0x5FFF, 
0x02D5, 0x00DF, 0xCCE2, 0xFFFF, 0xF01F, 0x6CCB, 0xFFFF, 0x001F, 0x4AD7, 
0xFFFF, 0xD01F, 0x6CC7, 0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD01F, 0x28FF, 
0xFFFF, 0xA71F, 0x2AFF, 0xFFFF, 0xA71F, 0x6CE2, 0xFFFF, 0xE31F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x0310, 0x005F, 0x5FFF, 0x033E, 0x003F, 0x5FFF, 
0xFFFF, 0x0006, 0xCC2E, 0xFFFF, 0x00FF, 0xCC2F, 0x0408, 0x003F, 0x5FFF, 
0x0408, 0x003F, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 0x02EC, 0xC83F, 0x28FF, 
0x0408, 0x003F, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 0x0408, 0x003F, 0x5FFF, 
0x02EC, 0xC83F, 0x28FF, 0xFFFF, 0x001F, 0xCC2E, 0xFFFF, 0x001F, 0xCC2F, 
0xFFFF, 0xC81F, 0x28FF, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0x001F, 0x48C1, 
0xFFFF, 0xD41F, 0x6C00, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xD004, 0x28FF, 
0x0313, 0xFDDF, 0x6CC2, 0xFFFF, 0x001F, 0xCC00, 0xFFFF, 0xE01F, 0x6CE3, 
0xFFFF, 0xE207, 0x6CE3, 0x0349, 0x0047, 0xCCE2, 0x02F8, 0xEADF, 0x6CCC, 
0xFFFF, 0xF01F, 0x6CCB, 0xFFFF, 0xF41F, 0x6CCB, 0xFFFF, 0xF11F, 0x6CCB, 
0xFFFF, 0x001F, 0x4AD7, 0xFFFF, 0xD01F, 0x6CC7, 0xFFFF, 0x001F, 0xCC12, 
0xFFFF, 0xD01F, 0x28FF, 0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xFD1F, 0x6CC2, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xEA1F, 0x6CE4, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xFD1F, 0x6CC2, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xF41F, 0x6CE3, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xFD1F, 0x6CC2, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xF11F, 0x6CE3, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xCF1F, 0x2AFF, 
0x034B, 0x003F, 0x5FFF, 0xFFFF, 0x001F, 0xCC00, 0xFFFF, 0xE01F, 0x6CE3, 
0xFFFF, 0x0007, 0xCCE2, 0x0348, 0x0050, 0x49FF, 0xFFFF, 0xE1FF, 0x6CCC, 
0x0328, 0x003F, 0x58CB, 0x0328, 0x003F, 0x58CB, 0x0328, 0x003F, 0x58CB, 
0x0328, 0x003F, 0x58CB, 0x0328, 0x003F, 0x59CB, 0x0328, 0x003F, 0x59CB, 
0x0328, 0x003F, 0x59CB, 0x0328, 0x003F, 0x59CB, 0x0328, 0x003F, 0x58CB, 
0x0328, 0x003F, 0x58CB, 0x0328, 0x003F, 0x5ACB, 0x0328, 0x003F, 0x5ACB, 
0x0328, 0x003F, 0x59CB, 0x0328, 0x003F, 0x59CB, 0x0328, 0x003F, 0x5BCB, 
0x0328, 0x003F, 0x5BCB, 0xFFFF, 0x001F, 0x4AD7, 0xFFFF, 0xD01F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD01F, 0x28FF, 0xFFFF, 0xA71F, 0x2AFF, 
0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0x9A1F, 0x6CE3, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xF41F, 0x6CE3, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0xA71F, 0x6CE2, 0xFFFF, 0xE31F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x0310, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x5FDA, 0xFFFF, 0xD01F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xEA1F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x0346, 0xBE5F, 0x6CE3, 0xFFFF, 0xFC1F, 0x6CC0, 
0xFFFF, 0xBE1F, 0x6CE3, 0xFFFF, 0xCF1F, 0x2AFF, 0x034B, 0x003F, 0x5FFF, 
0xFFFF, 0x001F, 0x5FDA, 0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xBC1F, 0x2AFF, 
0xFFFF, 0xC81F, 0x6CC7, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xCA1F, 0x28FF, 
0xFFFF, 0xCA1F, 0x6CC6, 0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xC81F, 0x6CC7, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xCA1F, 0x6CC6, 0x0005, 0x001F, 0x5CC0, 
0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0x001F, 0x5400, 0xFFFF, 0x001F, 0x893F, 
0xFFFF, 0x001F, 0x953F, 0xFFFF, 0x001F, 0x963F, 0xFFFF, 0xFD1F, 0x6CC0, 
0xFFFF, 0x000E, 0x893F, 0xFFFF, 0xA9FF, 0x283F, 0x0360, 0x0024, 0x5FFF, 
0x0360, 0x0024, 0x5FFF, 0x0360, 0xA924, 0x28FF, 0x0360, 0xA924, 0x28FF, 
0x0408, 0xC95F, 0x28FF, 0xFFFF, 0xBC1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 
0x0408, 0x005F, 0x5FFF, 0xFFFF, 0xFC13, 0x6CFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x0376, 0x003F, 0x5FFF, 
0x0388, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0x0376, 0x003F, 0x5FFF, 0x0388, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0x0376, 0x003F, 0x5FFF, 0x0388, 0x003F, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x0376, 0x003F, 0x5FFF, 
0x0388, 0x003F, 0x5FFF, 0xFFFF, 0xFD10, 0x6CFF, 0xFFFF, 0xDBFF, 0x6CC0, 
0x039B, 0x003F, 0x5FFF, 0x03A5, 0xE43F, 0x6CE3, 0x03F2, 0x003F, 0x5FFF, 
0x03AB, 0xDA3F, 0x6CC0, 0x03AD, 0x003F, 0x5FFF, 0x03BF, 0x003F, 0x5FFF, 
0x03D5, 0xD43F, 0x6CC0, 0x03D9, 0xD43F, 0x6CC0, 0x03DD, 0xDA3F, 0x6CC0, 
0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xFD10, 0x6CFF, 
0xFFFF, 0xFDFF, 0x6CC2, 0x03F2, 0x003F, 0x5FFF, 0x0459, 0x003F, 0x5FFF, 
0x03DF, 0x003F, 0x5F3F, 0x03E4, 0x003F, 0x5F3F, 0x0459, 0x003F, 0x5FFF, 
0x0459, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xE11F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x03F2, 0xF3DF, 0x6CE3, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xE11F, 0x6CE4, 0x03F2, 0x003F, 0x8AF2, 
0xFFFF, 0xE607, 0x6CE3, 0x03A9, 0x00C7, 0x5FFF, 0x03F2, 0x00DF, 0x5FEA, 
0x03F2, 0x003F, 0x5FFE, 0x03F2, 0x00DF, 0x5FFF, 0x03F2, 0x003F, 0x5FFE, 
0xFFFF, 0xE41F, 0x6CE4, 0x03F2, 0xDA3F, 0x2AFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCB, 0xFFFF, 0xFD07, 0x6CD8, 0x03B8, 0x005F, 0x5FF4, 
0xFFFF, 0x001F, 0x5FFF, 0xFFFF, 0x001F, 0x52E2, 0xFFFF, 0xB61F, 0x6CCC, 
0xFFFF, 0xB61F, 0x2AFF, 0xFFFF, 0x001F, 0x53E2, 0xFFFF, 0xB71F, 0x6CCC, 
0x03F2, 0xB73F, 0x2AFF, 0xFFFF, 0x001F, 0x5FFF, 0xFFFF, 0x001F, 0x52E2, 
0xFFFF, 0xB41F, 0x6CCC, 0xFFFF, 0xB41F, 0x2AFF, 0xFFFF, 0x001F, 0x53E2, 
0xFFFF, 0xB51F, 0x6CCC, 0x03F2, 0xB53F, 0x2AFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCB, 0xFFFF, 0xFD07, 0x6CD8, 0x03CC, 0x005F, 0x5FF4, 
0xFFFF, 0x001F, 0x5FFF, 0xFFFF, 0x001F, 0x52E2, 0xFFFF, 0x001F, 0x5FC9, 
0xFFFF, 0xB61F, 0x6CCB, 0xFFFF, 0xB61F, 0x2AFF, 0xFFFF, 0x001F, 0x53E2, 
0xFFFF, 0x001F, 0x5FC9, 0xFFFF, 0xB71F, 0x6CCB, 0x03F2, 0xB73F, 0x2AFF, 
0xFFFF, 0x001F, 0x5FFF, 0xFFFF, 0x001F, 0x52E2, 0xFFFF, 0x001F, 0x5FC9, 
0xFFFF, 0xB41F, 0x6CCB, 0xFFFF, 0xB41F, 0x2AFF, 0xFFFF, 0x001F, 0x53E2, 
0xFFFF, 0x001F, 0x5FC9, 0xFFFF, 0xB51F, 0x6CCB, 0x03F2, 0xB53F, 0x2AFF, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xE21F, 0x6CE4, 
0x03F2, 0x003F, 0x8AF2, 0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xF21F, 0x6CE3, 0x03F2, 0x003F, 0x8AF2, 0xFFFF, 0xE31F, 0x6CE4, 
0x03F2, 0xDA3F, 0x2AFF, 0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xE41F, 0x6CCB, 
0xFFFF, 0x0007, 0x5F3F, 0x03E7, 0x00DF, 0xCCC0, 0x03E7, 0xA63F, 0x6CC0, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0x000B, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x03F1, 0x003F, 0x5FFF, 
0x03F1, 0x003F, 0x5FFF, 0x03F1, 0x003F, 0x5FFF, 0x03F1, 0x003F, 0x5FFF, 
0x03E7, 0x003F, 0x5FFF, 0x03E7, 0x003F, 0x5FFF, 0x03E7, 0x003F, 0x5FFF, 
0x03E7, 0x003F, 0x5FFF, 0x03FF, 0x003F, 0x49D6, 0xFFFF, 0x000B, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x03FC, 0x003F, 0x5FFF, 0x03FC, 0x003F, 0x5FFF, 
0x03FC, 0x003F, 0x5FFF, 0x03FC, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 0x03F2, 0x003F, 0x5FFF, 
0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0x001F, 0xCC16, 0xFFFF, 0xC91F, 0x28FF, 
0xFFFF, 0xCF1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 0x0408, 0x00DF, 0x5FFF, 
0xFFFF, 0xD01F, 0x6CC7, 0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD01F, 0x28FF, 
0xFFFF, 0xCF1F, 0x6CC7, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xCF1F, 0x28FF, 
0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xED1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x040F, 0x00DF, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE51F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0x0000, 0x5FFF, 0x0480, 0x005F, 0x5FFF, 
0xFFFF, 0xC21F, 0x6CE2, 0xFFFF, 0xB11F, 0x2AFF, 0x0480, 0x003F, 0x5FFF, 
0xFFFF, 0xDC1F, 0x6CEE, 0xFFFF, 0xDD1F, 0x6CEF, 0xFFFF, 0x0004, 0x5FFF, 
0x0459, 0x005F, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE51F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0x0001, 0x5FFF, 0x0458, 0x005F, 0x5FFF, 
0xFFFF, 0x001F, 0xCC2E, 0xFFFF, 0x001F, 0xCC2F, 0xFFFF, 0xC804, 0x28FF, 
0x0422, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x5FDA, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xE01F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x042B, 0x00DF, 0x5FFF, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xBC1F, 0x2AFF, 0x0443, 0x003F, 0x5FFF, 0xFFFF, 0xE51F, 0x6CE2, 
0xFFFF, 0x0007, 0x5FFF, 0x0443, 0x00DF, 0x5FFF, 0xFFFF, 0x0006, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x0443, 0x003F, 0x5FFF, 0x0443, 0x003F, 0x5FFF, 
0x0443, 0x003F, 0x5FFF, 0x0443, 0x003F, 0x5FFF, 0x0443, 0x003F, 0x5FFF, 
0x0443, 0x003F, 0x5FFF, 0x0443, 0x003F, 0x5FFF, 0x0438, 0x003F, 0x5FFF, 
0xFFFF, 0xFD1F, 0x6CC0, 0x001F, 0x001F, 0x5CE3, 0x0011, 0x001F, 0x5CCD, 
0xFFFF, 0xDB07, 0x6CC0, 0x0443, 0xE45F, 0x6CE3, 0xFFFF, 0xE607, 0x6CE3, 
0x0441, 0x00C7, 0x5FFF, 0x0443, 0x00DF, 0x5FEA, 0x0443, 0x003F, 0x5FFE, 
0x0443, 0x00DF, 0x5FFF, 0x0443, 0x003F, 0x5FFE, 0xFFFF, 0xC81F, 0x6CC7, 
0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xCA1F, 0x28FF, 0xFFFF, 0xCA1F, 0x6CC6, 
0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xC81F, 0x6CC7, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0xCA1F, 0x6CC6, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCC00, 
0xFFFF, 0xD01F, 0x293F, 0x0002, 0x001F, 0x5CC0, 0xFFFF, 0x001F, 0x48C5, 
0xFFFF, 0x001F, 0x5400, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0x953F, 
0xFFFF, 0x001F, 0x963F, 0xFFFF, 0xFD1F, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 
0xFFFF, 0x001F, 0x5F3F, 0x0458, 0xC93F, 0x28FF, 0x0480, 0x003F, 0x5FFF, 
0xFFFF, 0xDB1F, 0x6CE2, 0xFFFF, 0xE71F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x046D, 0x005F, 0x5FFF, 0xFFFF, 0xFC1F, 0x6CC0, 0xFFFF, 0xED1F, 0x6CE3, 
0xFFFF, 0xEC07, 0x6CE3, 0x0462, 0x00C7, 0x5FFF, 0x0464, 0x005F, 0x5FFF, 
0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xA31F, 0x2AFF, 0x0480, 0x003F, 0x5FE9, 
0xFFFF, 0xDB1F, 0x6CE2, 0xFFFF, 0xE71F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x046D, 0x005F, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE11F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0x0462, 0x003F, 0x5FFF, 0xFFFF, 0x001F, 0x5FF0, 
0xFFFF, 0x001F, 0x5FF8, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE61F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x0477, 0x00DF, 0x5FFF, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xF61F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 0x01BA, 0x003F, 0x5FFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE01F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x01BA, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x5FE9, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xE01F, 0x6CCC, 0xFFFF, 0xF81F, 0x2AFF, 0x01BA, 0x003F, 0x5FFF, 
0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0xA11F, 0x2AFF, 0xFFFF, 0xC91F, 0x6CE2, 
0xFFFF, 0xA21F, 0x2AFF, 0xFFFF, 0xCA1F, 0x6CE2, 0xFFFF, 0xCB1F, 0x2AFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF01F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xF800, 0x6CC0, 0x048E, 0xE55F, 0x6CE4, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xC61F, 0x6CE2, 0xFFFF, 0xC71F, 0x2AFF, 0xFFFF, 0xFD1F, 0x6CE2, 
0xFFFF, 0xA01F, 0x2AFF, 0xFFFF, 0xFC01, 0x6CC0, 0x0499, 0xE65F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x0499, 0x005F, 0x5FFF, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0xFD1F, 0x6C00, 
0xFFFF, 0x001F, 0x89FF, 0xFFFF, 0xDB02, 0x6CC0, 0x01BA, 0xD95F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x049F, 0xE2DF, 0x6CE3, 
0xFFFF, 0xE31F, 0x6CE3, 0xFFFF, 0xDA07, 0x6CC0, 0x01BA, 0xE25F, 0x6CE3, 
0xFFFF, 0xCC07, 0x6CC6, 0x04AF, 0x005F, 0x5F3F, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0x5400, 
0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0x953F, 0xFFFF, 0x001F, 0x963F, 
0xFFFF, 0xFD1F, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0xD91F, 0x6CC0, 
0xFFFF, 0x001F, 0x893F, 0x04B5, 0xCD3F, 0x28FF, 0xFFFF, 0xCD1F, 0x6CC7, 
0xFFFF, 0xFD1F, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0xFE1F, 0x6CC0, 
0xFFFF, 0x001F, 0x893F, 0x04B5, 0xCD3F, 0x28FF, 0xFFFF, 0xD61F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC3, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0x001F, 0xCC2E, 
0xFFFF, 0x001F, 0xCC2F, 0xFFFF, 0xFF04, 0x28FF, 0x01BA, 0x0045, 0x5FFF, 
0xFFFF, 0x001F, 0xCC00, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0x001F, 0x5F7F, 
0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0xFF07, 0x6CC7, 0x04C7, 0x005F, 0x5F3F, 
0xFFFF, 0x001F, 0x89FF, 0xFFFF, 0xF91F, 0x6CE2, 0xFFFF, 0xE71F, 0x6CCC, 
0xFFFF, 0xF91F, 0x2AFF, 0x04CB, 0x003F, 0x5FFF, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0xF91F, 0x6CE2, 0xFFFF, 0xF71F, 0x6CCB, 0xFFFF, 0xF91F, 0x2AFF, 
0x01BA, 0x003F, 0x5FDE, 0xFFFF, 0xFE1F, 0x29FF, 0xFFFF, 0xD91F, 0x6CE4, 
0xFFFF, 0xD91F, 0x2AFF, 0xFFFF, 0xE11F, 0x6CE3, 0xFFFF, 0xFD07, 0x6CE2, 
0x055C, 0xEA5F, 0x6CCB, 0xFFFF, 0xFD07, 0x6CD8, 0x055C, 0xD5DF, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC3, 0xFFFF, 0x0001, 0xCCC4, 0xFFFF, 0x00FF, 0xCC2E, 
0x056D, 0x003F, 0x5FFF, 0x0561, 0x003F, 0x5FFF, 0x056D, 0x003F, 0x5FFF, 
0x04DF, 0x003F, 0xCC2F, 0x056D, 0x003F, 0x5FFF, 0x0561, 0x003F, 0x5FFF, 
0x056D, 0x003F, 0x5FFF, 0x04DF, 0x003F, 0xCC2F, 0xFFFF, 0xC81F, 0x28FF, 
0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0x001F, 0x48C1, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xD11F, 0x28FF, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0xCC00, 0xFFFF, 0xE01F, 0x6CE3, 
0xFFFF, 0xE207, 0x6CE3, 0x0530, 0x0047, 0xCCE2, 0x04ED, 0xF1C4, 0x6CCB, 
0xFFFF, 0xF004, 0x6CCB, 0x04EF, 0xF45F, 0x6CCB, 0x04F0, 0x9A3F, 0x6CCB, 
0x04F0, 0xEA3F, 0x6CCC, 0xFFFF, 0x001F, 0x4AD7, 0xFFFF, 0xD11F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD11F, 0x28FF, 0xFFFF, 0xA71F, 0x2AFF, 
0xFFFF, 0x0004, 0x5FFF, 0x0509, 0x00DF, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xEA1F, 0x6CE4, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xF41F, 0x6CE3, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xB81F, 0x6CE2, 
0xFFFF, 0xCF1F, 0x2AFF, 0x0533, 0x003F, 0x5FFF, 0xFFFF, 0xFC1F, 0x6CE2, 
0xFFFF, 0xEF1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x0515, 0x00DF, 0x5FFF, 
0xFFFF, 0xD41F, 0x6CC7, 0xFFFF, 0x001F, 0x5F27, 0xFFFF, 0xE01F, 0x6C99, 
0xFFFF, 0x001F, 0xCCE6, 0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0x0009, 0xCCE6, 
0x0512, 0x005F, 0x8A32, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0x9A1F, 0x6CE3, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xFD1F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xF41F, 0x6CE3, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xA71F, 0x6CE2, 
0xFFFF, 0xE31F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x0506, 0x005F, 0x5FFF, 
0xFFFF, 0xD11F, 0x6CC7, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xEA1F, 0x6CE3, 0xFFFF, 0x0007, 0x5FFF, 0x052D, 0xBE5F, 0x6CE3, 
0xFFFF, 0xFC1F, 0x6CC0, 0xFFFF, 0xBE1F, 0x6CE3, 0xFFFF, 0xCF1F, 0x2AFF, 
0xFFFF, 0x001F, 0x5FDB, 0x0533, 0x003F, 0x5FFF, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xBF1F, 0x2AFF, 0xFFFF, 0x001F, 0x5FDB, 0xFFFF, 0xC81F, 0x6CC7, 
0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xCA1F, 0x28FF, 0xFFFF, 0xCA1F, 0x6CC6, 
0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xC81F, 0x6CC7, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0xCA1F, 0x6CC6, 0x0006, 0x001F, 0x5CC0, 0xFFFF, 0x001F, 0x48C5, 
0xFFFF, 0x001F, 0x54C0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0x953F, 
0xFFFF, 0x001F, 0x963F, 0xFFFF, 0xFD1F, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 
0xFFFF, 0xA91F, 0x283F, 0xFFFF, 0xC91F, 0x283F, 0xFFFF, 0xCF1F, 0x6CE2, 
0xFFFF, 0x0007, 0x5FFF, 0x056D, 0x00DF, 0x5FFF, 0xFFFF, 0x000B, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x0552, 0x003F, 0x5FFF, 0x0552, 0x003F, 0x5FFF, 
0x0552, 0x003F, 0x5FFF, 0x0552, 0x003F, 0x5FFF, 0x0548, 0x003F, 0x5FFF, 
0x0548, 0x003F, 0x5FFF, 0x0548, 0x003F, 0x5FFF, 0x0548, 0x003F, 0x5FFF, 
0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0x001F, 0xCC16, 0xFFFF, 0xC91F, 0x28FF, 
0xFFFF, 0xD11F, 0x6CC7, 0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD11F, 0x28FF, 
0xFFFF, 0xCF1F, 0x6CC7, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xCF1F, 0x28FF, 
0x056D, 0x003F, 0x5FFF, 0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xA31F, 0x2AFF, 
0xFFFF, 0x001F, 0x5FF0, 0xFFFF, 0x001F, 0x5FF8, 0x0571, 0x003F, 0x5FE9, 
0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xEF1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x056D, 0x00DF, 0x5FFF, 0xFFFF, 0xD41F, 0x6CC7, 0xFFFF, 0x001F, 0x5F27, 
0xFFFF, 0xE01F, 0x6C99, 0xFFFF, 0x001F, 0xCCE6, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0x0009, 0xCCE6, 0x056A, 0x005F, 0x8A32, 0xFFFF, 0x001F, 0x5F7F, 
0xFFFF, 0x0000, 0x5FFF, 0x0571, 0x005F, 0x5FFF, 0xFFFF, 0xC21F, 0x6CE2, 
0xFFFF, 0xB11F, 0x2AFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE21F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0x048E, 0x003F, 0x5FFF, 0xFFFF, 0xFE10, 0x29FF, 
0x066B, 0x00DF, 0x5FFF, 0xFFFF, 0xC700, 0x6CC7, 0x05AF, 0x005F, 0xCCC0, 
0xFFFF, 0xEA1F, 0x6CE3, 0xFFFF, 0xC507, 0x6CC0, 0x059F, 0xFDDF, 0x6CE3, 
0xFFFF, 0xBA07, 0x6CC7, 0x059F, 0x00DF, 0xCCE2, 0xFFFF, 0xFC07, 0x6CC0, 
0x059F, 0xEEDF, 0x6CE3, 0xFFFF, 0xED07, 0x6CE3, 0x0584, 0xECC7, 0x6CE3, 
0x0589, 0x00C7, 0x5FFF, 0x0589, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x5FD1, 
0xFFFF, 0x001F, 0x5FE9, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF11F, 0x6CCB, 
0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xBA1F, 0x6CC7, 0xFFFF, 0x001F, 0xCC00, 
0xFFFF, 0xE11F, 0x6CE5, 0xFFFF, 0xBA1F, 0x28FF, 0xFFFF, 0xC71F, 0x6CC7, 
0xFFFF, 0x0007, 0xCCC0, 0x0591, 0x995F, 0x6CE3, 0xFFFF, 0xE91F, 0x6CE4, 
0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0x001F, 0x48C8, 
0xFFFF, 0xC11F, 0x29FF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE41F, 0x6CCC, 
0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE31F, 0x6CCC, 
0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE21F, 0x6CCC, 
0xFFFF, 0xF81F, 0x2AFF, 0x05AA, 0x003F, 0x5FFF, 0xFFFF, 0xC71F, 0x6CC7, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0x991F, 0x6CE3, 0xFFFF, 0x9B1F, 0x6CCB, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF31F, 0x6CCB, 
0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF21F, 0x6CCB, 
0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xC71F, 0x6CC7, 0x0008, 0x001F, 0x5CC0, 
0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0xFD1F, 0x6C40, 0xFFFF, 0x001F, 0x89FF, 
0xFFFF, 0xFC13, 0x6CFF, 0xFFFF, 0x00FF, 0x5FFF, 0x0625, 0x003F, 0x5FFF, 
0x0625, 0x003F, 0x5FFF, 0x0625, 0x003F, 0x5FFF, 0x0625, 0x003F, 0x5FFF, 
0x05CF, 0x003F, 0x5FFF, 0x05CF, 0x003F, 0x5FFF, 0x05C1, 0x003F, 0x5FFF, 
0x05CF, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 
0x0627, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 0x05CF, 0x003F, 0x5FFF, 
0x05CF, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 
0xFFFF, 0x000C, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x05C1, 0x003F, 0x5FFF, 
0x05C1, 0x003F, 0x5FFF, 0x05C1, 0x003F, 0x5FFF, 0x05C1, 0x003F, 0x5FFF, 
0x0625, 0x003F, 0x5FFF, 0x0625, 0x003F, 0x5FFF, 0x05CB, 0x003F, 0x5FFF, 
0x05CB, 0x003F, 0x5FFF, 0xFFFF, 0xD91F, 0x6CE2, 0xFFFF, 0xE01F, 0x6CCC, 
0xFFFF, 0xD91F, 0x2AFF, 0x0625, 0x003F, 0x5FFF, 0xFFFF, 0xFC1F, 0x6CC0, 
0xFFFF, 0xEB1F, 0x6CE3, 0xFFFF, 0xEF07, 0x6CE3, 0x0603, 0x00C7, 0x5FFF, 
0x05F2, 0x005F, 0x5FFF, 0xFFFF, 0xFE1F, 0x6CC0, 0xFFFF, 0xE11F, 0x6CE3, 
0xFFFF, 0xFD07, 0x6CC0, 0x05DB, 0xEA5F, 0x6CE3, 0xFFFF, 0xE307, 0x6CE3, 
0x0627, 0x0047, 0x5FFF, 0x0627, 0x005F, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 
0x0627, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 
0x0627, 0x003F, 0x5FFF, 0x0627, 0x003F, 0x5FFF, 0x05E5, 0x003F, 0x5FFF, 
0xFFFF, 0xBF1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 0x0627, 0x005F, 0x5FFF, 
0xFFFF, 0xCF1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 0x0627, 0x00DF, 0x5FFF, 
0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0x001F, 0xCC16, 0xFFFF, 0xC91F, 0x28FF, 
0xFFFF, 0xD11F, 0x6CC7, 0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD11F, 0x28FF, 
0x0620, 0x003F, 0x5FFF, 0xFFFF, 0xFE1F, 0x6CC0, 0xFFFF, 0xE11F, 0x6CE3, 
0xFFFF, 0xFD07, 0x6CC0, 0x05F9, 0xEA5F, 0x6CE3, 0xFFFF, 0xE307, 0x6CE3, 
0x0624, 0x0047, 0x5FFF, 0x0624, 0x005F, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x0620, 0x003F, 0x5FFF, 0x0620, 0x003F, 0x5FFF, 
0x0620, 0x003F, 0x5FFF, 0x0625, 0x003F, 0x5FFF, 0x0620, 0x003F, 0x5FFF, 
0x0620, 0x003F, 0x5FFF, 0x0620, 0x003F, 0x5FFF, 0x05E5, 0x003F, 0x5FFF, 
0xFFFF, 0xFE1F, 0x6CC0, 0xFFFF, 0xE11F, 0x6CE3, 0xFFFF, 0xFD07, 0x6CC0, 
0x060A, 0xEA5F, 0x6CE3, 0xFFFF, 0xE307, 0x6CE3, 0x0624, 0x0047, 0x5FFF, 
0x0624, 0x005F, 0x5FFF, 0xFFFF, 0x0006, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x0620, 0x003F, 0x5FFF, 0x0620, 0x003F, 0x5FFF, 0x0620, 0x003F, 0x5FFF, 
0x0625, 0x003F, 0x5FFF, 0x0620, 0x003F, 0x5FFF, 0x0620, 0x003F, 0x5FFF, 
0x0620, 0x003F, 0x5FFF, 0x0614, 0x003F, 0x5FFF, 0xFFFF, 0xBC1F, 0x6CE2, 
0xFFFF, 0x0007, 0x5FFF, 0x0627, 0x005F, 0x5FFF, 0xFFFF, 0xCF1F, 0x6CE2, 
0xFFFF, 0x0007, 0x5FFF, 0x0627, 0x00DF, 0x5FFF, 0xFFFF, 0xC91F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC16, 0xFFFF, 0xC91F, 0x28FF, 0xFFFF, 0xD01F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD01F, 0x28FF, 0xFFFF, 0xCF1F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xCF1F, 0x28FF, 0x0627, 0x003F, 0x5FFF, 
0x0625, 0x003F, 0x5FE9, 0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xA31F, 0x2AFF, 
0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0xA41F, 0x2AFF, 0xFFFF, 0xFC1F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x0637, 0x00DF, 0x5FFF, 
0xFFFF, 0x0001, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x0645, 0x003F, 0x5FFF, 
0x0645, 0x003F, 0x5FFF, 0x0645, 0x003F, 0x5FFF, 0x0641, 0x003F, 0x5FFF, 
0x0645, 0x003F, 0x5FFF, 0x0645, 0x003F, 0x5FFF, 0x0645, 0x003F, 0x5FFF, 
0x0641, 0x003F, 0x5FFF, 0xFFFF, 0x0006, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x0645, 0x003F, 0x5FFF, 0x0645, 0x003F, 0x5FFF, 0x0645, 0x003F, 0x5FFF, 
0x0641, 0x003F, 0x5FFF, 0x0645, 0x003F, 0x5FFF, 0x0645, 0x003F, 0x5FFF, 
0x0645, 0x003F, 0x5FFF, 0x0641, 0x003F, 0x5FFF, 0xFFFF, 0xA91F, 0x6CC7, 
0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xA91F, 0x28FF, 
0xFFFF, 0xFD1F, 0x6CC0, 0xFFFF, 0xA01F, 0x6CE5, 0xF800, 0x001F, 0x5CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x064D, 0x00DF, 0x5FFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xEA1F, 0x6CCC, 0xFFFF, 0xD91F, 0x2AFF, 0xFFFF, 0xD91F, 0x6CC0, 
0xFFFF, 0xFE1F, 0x6CE5, 0xFFFF, 0xEB1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x0655, 0x00DF, 0x5FFF, 0xFFFF, 0xD91F, 0x6CE2, 0xFFFF, 0xED1F, 0x6CCC, 
0xFFFF, 0xD91F, 0x2AFF, 0xFFFF, 0xD91F, 0x6CE2, 0xFFFF, 0xFE1F, 0x6CCC, 
0xFFFF, 0xD91F, 0x2AFF, 0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0xEA1F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x065F, 0x00DF, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0x0002, 0x5FFF, 
0x01BA, 0x005F, 0x5FFF, 0xFFFF, 0x0005, 0x5FFF, 0x01BA, 0x005F, 0x5FFF, 
0xFFFF, 0xCD1F, 0x6CC7, 0xFFFF, 0x001F, 0x46C0, 0xFFFF, 0x001F, 0x893F, 
0xFFFF, 0xFD1F, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0xFE1F, 0x6CC0, 
0xFFFF, 0x001F, 0x893F, 0x01BA, 0xCD3F, 0x28FF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xFE1F, 0x6CCC, 0xFFFF, 0xD91F, 0x2AFF, 0xFFFF, 0x0006, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x067B, 0x003F, 0x5FFF, 0x067B, 0x003F, 0x5FFF, 
0x067B, 0x003F, 0x5FFF, 0x067B, 0x003F, 0x5FFF, 0x067B, 0x003F, 0x5FFF, 
0x067B, 0x003F, 0x5FFF, 0x067B, 0x003F, 0x5FFF, 0x0678, 0x003F, 0x5FFF, 
0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0x0002, 0x5FFF, 0x01BA, 0x0045, 0x5FFF, 0x01BA, 0xCD5F, 0x6CC7, 
0xFFFF, 0xFD1F, 0x6CE2, 0x01BA, 0x003F, 0x8AF2, 0xFFFF, 0xFE10, 0x29FF, 
0x066B, 0x00DF, 0x5FFF, 0xFFFF, 0xC700, 0x6CC7, 0x06BB, 0x005F, 0xCCC0, 
0xFFFF, 0xEA1F, 0x6CE3, 0xFFFF, 0xC507, 0x6CC0, 0x06A7, 0xFDDF, 0x6CE3, 
0xFFFF, 0xBA07, 0x6CC7, 0x06A7, 0x00DF, 0xCCE2, 0xFFFF, 0x0007, 0x5FFF, 
0x06A7, 0x00DF, 0x5FFF, 0xFFFF, 0x001F, 0x5FD1, 0xFFFF, 0x001F, 0x5FE9, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF11F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE21F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x06B3, 0x005F, 0x5FFF, 0xFFFF, 0xBA1F, 0x6CC7, 0xFFFF, 0x001F, 0xCC00, 
0xFFFF, 0xE11F, 0x6CE5, 0xFFFF, 0xBA1F, 0x28FF, 0xFFFF, 0xC71F, 0x6CC7, 
0xFFFF, 0x0007, 0xCCC0, 0x069C, 0x995F, 0x6CE3, 0xFFFF, 0xE91F, 0x6CE4, 
0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0x001F, 0x48C8, 
0xFFFF, 0xC11F, 0x29FF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE41F, 0x6CCC, 
0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE31F, 0x6CCC, 
0xFFFF, 0xF81F, 0x2AFF, 0x06B3, 0x003F, 0x5FFF, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xE21F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x06B3, 0x005F, 0x5FFF, 
0xFFFF, 0xC71F, 0x6CC7, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0x991F, 0x6CE3, 
0xFFFF, 0x9B1F, 0x6CCB, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xF31F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xF21F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xC71F, 0x6CC7, 
0x0008, 0x001F, 0x5CC0, 0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0xFD1F, 0x6CC0, 
0x06BB, 0x003F, 0x89FF, 0xFFFF, 0x0006, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x06C9, 0x003F, 0x5FFF, 0x06C9, 0x003F, 0x5FFF, 0x06C9, 0x003F, 0x5FFF, 
0x06C5, 0x003F, 0x5FFF, 0x06C9, 0x003F, 0x5FFF, 0x06C9, 0x003F, 0x5FFF, 
0x06C9, 0x003F, 0x5FFF, 0x06C5, 0x003F, 0x5FFF, 0xFFFF, 0xA21F, 0x6CC7, 
0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xA21F, 0x28FF, 
0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xA31F, 0x2AFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xE21F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x06D5, 0x00DF, 0x5FFF, 
0x0000, 0x001F, 0x5CE2, 0xFFFF, 0xFE1F, 0x2AFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xEA1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0x06DD, 0x003F, 0x5FFF, 
0xFFFF, 0xFD1F, 0x6CC0, 0xFFFF, 0xA11F, 0x6CE5, 0xF800, 0x001F, 0x5CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x06DD, 0x00DF, 0x5FFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xEA1F, 0x6CCC, 0xFFFF, 0xD91F, 0x2AFF, 0x064D, 0x003F, 0x5FFF, 
0xFFFF, 0xFE1F, 0x29FF, 0xFFFF, 0xD91F, 0x6CE4, 0xFFFF, 0xD91F, 0x2AFF, 
0xFFFF, 0xFC13, 0x6CC0, 0xFFFF, 0xBEFF, 0x6CE3, 0x06F3, 0xD93F, 0x6CC0, 
0x06F3, 0xD93F, 0x6CC0, 0x0865, 0x003F, 0x5FFF, 0x06F3, 0xD93F, 0x6CC0, 
0x06F5, 0x003F, 0x5FFF, 0x06F5, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x06F5, 0x003F, 0x5FFF, 0x06F4, 0x003F, 0x5FFF, 0x06F4, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x06F4, 0x003F, 0x5FFF, 0x07EF, 0x003F, 0x5FFF, 
0x07EF, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0733, 0x0027, 0x5FFF, 0x07D1, 0x0027, 0x5FFF, 0xFFFF, 0x0000, 0x5FFF, 
0x06FB, 0x005F, 0x5FFF, 0xFFFF, 0xB11F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 
0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xB11F, 0x28FF, 0xFFFF, 0xFC1F, 0x6CC0, 
0xFFFF, 0xEB1F, 0x6CE3, 0xFFFF, 0xBE07, 0x6CE3, 0x079C, 0xD947, 0x6CC0, 
0x071A, 0x00DF, 0x5FFF, 0xFFFF, 0xBC1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 
0x084C, 0x005F, 0x5FFF, 0xFFFF, 0xCF1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 
0x0865, 0x00DF, 0x5FFF, 0xFFFF, 0x0006, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0710, 0x003F, 0x5FFF, 0xFFFF, 0xC91F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC16, 0xFFFF, 0xC91F, 0x28FF, 0xFFFF, 0xD01F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD01F, 0x28FF, 0xFFFF, 0xCF1F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xCF1F, 0x28FF, 0x0865, 0x003F, 0x5FFF, 
0xFFFF, 0x000C, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x071A, 0x003F, 0x5FFF, 
0x071A, 0x003F, 0x5FFF, 0x071A, 0x003F, 0x5FFF, 0x071A, 0x003F, 0x5FFF, 
0x0728, 0x003F, 0x5FFF, 0x0728, 0x003F, 0x5FFF, 0x0724, 0x003F, 0x5FFF, 
0x0724, 0x003F, 0x5FFF, 0xFFFF, 0xD91F, 0x6CE2, 0xFFFF, 0xE01F, 0x6CCC, 
0xFFFF, 0xD91F, 0x2AFF, 0x072D, 0x003F, 0x5FFF, 0xFFFF, 0xA41F, 0x6CC0, 
0xFFFF, 0xEA1F, 0x6CE3, 0xFFFF, 0xE307, 0x6CE3, 0x072F, 0x0047, 0x5FFF, 
0x072F, 0x005F, 0x5FFF, 0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xA31F, 0x2AFF, 
0xFFFF, 0xBC1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 0x084C, 0x005F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0743, 0xE1DF, 0x6CE3, 0xFFFF, 0x0006, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x073E, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x073E, 0x003F, 0x5FFF, 
0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0xC91F, 0x28FF, 0x0865, 0x003F, 0x5FFF, 0xFFFF, 0xD407, 0x6CC0, 
0x0807, 0xA05F, 0x6CC2, 0xFFFF, 0x0006, 0xCC00, 0xFFFF, 0xE2FF, 0x6CE3, 
0x074F, 0x003F, 0x5FFF, 0x074F, 0x003F, 0x5FFF, 0x074F, 0x003F, 0x5FFF, 
0x0759, 0x0027, 0xCCE2, 0x074F, 0x003F, 0x5FFF, 0x074F, 0x003F, 0x5FFF, 
0x074F, 0x003F, 0x5FFF, 0x0771, 0x0027, 0xCCE2, 0xFFFF, 0x000C, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x074F, 0x003F, 0x5FFF, 0x074F, 0x003F, 0x5FFF, 
0x074F, 0x003F, 0x5FFF, 0x074F, 0x003F, 0x5FFF, 0x0798, 0x003F, 0x5FFF, 
0x0798, 0x003F, 0x5FFF, 0x0841, 0x003F, 0x5FFF, 0x0841, 0x003F, 0x5FFF, 
0x075B, 0xEADF, 0x6CCC, 0xFFFF, 0xF01F, 0x6CCB, 0xFFFF, 0xF41F, 0x6CCB, 
0xFFFF, 0xF11F, 0x6CCB, 0xFFFF, 0x000C, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x075D, 0x003F, 0x5FFF, 0x075D, 0x003F, 0x5FFF, 0x075D, 0x003F, 0x5FFF, 
0x075D, 0x003F, 0x5FFF, 0x0767, 0x003F, 0x5FFF, 0x0767, 0x003F, 0x5FFF, 
0x0837, 0x003F, 0x5FFF, 0x0837, 0x003F, 0x5FFF, 0xFFFF, 0x0010, 0x49FF, 
0x078A, 0x00DF, 0x4AD7, 0xFFFF, 0xA71F, 0x28FF, 0xFFFF, 0xD01F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD01F, 0x28FF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0x078A, 0x003F, 0x5FFF, 
0x0773, 0x9ADF, 0x6CCB, 0xFFFF, 0xF01F, 0x6CCB, 0xFFFF, 0xF41F, 0x6CCB, 
0xFFFF, 0xF11F, 0x6CCB, 0xFFFF, 0x000C, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x0775, 0x003F, 0x5FFF, 0x0775, 0x003F, 0x5FFF, 0x0775, 0x003F, 0x5FFF, 
0x0775, 0x003F, 0x5FFF, 0x077F, 0x003F, 0x5FFF, 0x077F, 0x003F, 0x5FFF, 
0x0837, 0x003F, 0x5FFF, 0x0837, 0x003F, 0x5FFF, 0xFFFF, 0x0010, 0x49FF, 
0x078A, 0x00DF, 0x4AD7, 0xFFFF, 0xA71F, 0x28FF, 0xFFFF, 0xD01F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD01F, 0x28FF, 0xFFFF, 0xA71F, 0x6CC7, 
0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0x9A1F, 0x6CCB, 0xFFFF, 0xF41F, 0x6CCB, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xEB1F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x0793, 0x005F, 0x5FFF, 0xFFFF, 0xC91F, 0x6CC7, 
0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xC91F, 0x28FF, 
0x0797, 0x003F, 0x5FFF, 0xFFFF, 0xA21F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 
0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xA21F, 0x28FF, 0xFFFF, 0xA91F, 0x28FF, 
0xFFFF, 0xBF1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 0x0856, 0x005F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x07C5, 0xE1DF, 0x6CE3, 0xFFFF, 0x0006, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x07AB, 0x003F, 0x5FFF, 0x07AB, 0x003F, 0x5FFF, 
0x07AB, 0x003F, 0x5FFF, 0x07A7, 0x003F, 0x5FFF, 0x07AB, 0x003F, 0x5FFF, 
0x07AB, 0x003F, 0x5FFF, 0x07AB, 0x003F, 0x5FFF, 0x07A7, 0x003F, 0x5FFF, 
0xFFFF, 0xA21F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0xA21F, 0x28FF, 0xFFFF, 0xBF1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 
0x0856, 0x005F, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x07B8, 0x003F, 0x5FFF, 0xFFFF, 0xCF1F, 0x6CE2, 
0xFFFF, 0x0007, 0x5FFF, 0x0865, 0x00DF, 0x5FFF, 0xFFFF, 0xC91F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC16, 0xFFFF, 0xC91F, 0x28FF, 0xFFFF, 0xD11F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC12, 0xFFFF, 0xD11F, 0x28FF, 0xFFFF, 0xCF1F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xCF1F, 0x28FF, 0x0865, 0x003F, 0x5FFF, 
0xFFFF, 0xD407, 0x6CC0, 0x081F, 0xA15F, 0x6CC2, 0xFFFF, 0x000C, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x07C7, 0x003F, 0x5FFF, 0x07C7, 0x003F, 0x5FFF, 
0x07C7, 0x003F, 0x5FFF, 0x07C7, 0x003F, 0x5FFF, 0x0745, 0x003F, 0x5FFF, 
0x0745, 0x003F, 0x5FFF, 0x0822, 0x003F, 0x5FFF, 0x0822, 0x003F, 0x5FFF, 
0x07D9, 0x00DF, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 0x0865, 0x005F, 0x5FFF, 
0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0xC91F, 0x28FF, 0x0865, 0x003F, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 
0x07DF, 0x005F, 0x5FFF, 0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 
0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xC91F, 0x28FF, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xA31F, 0x2AFF, 0xFFFF, 0xD91F, 0x6CE2, 0xFFFF, 0xE11F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x0848, 0x005F, 0x5FFF, 0xFFFF, 0x000C, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x07E5, 0x003F, 0x5FFF, 0x07E5, 0x003F, 0x5FFF, 
0x07E5, 0x003F, 0x5FFF, 0x07E5, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0845, 0x003F, 0x5FFF, 0x0845, 0x003F, 0x5FFF, 
0xFFFF, 0x0000, 0x5FFF, 0x07F5, 0x005F, 0x5FFF, 0xFFFF, 0xB11F, 0x6CC7, 
0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xB11F, 0x28FF, 
0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xBE1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x0800, 0x00DF, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 0x07AB, 0x005F, 0x5FFF, 
0xFFFF, 0xA21F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0xA21F, 0x28FF, 0x07AB, 0x003F, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 
0x07DF, 0x005F, 0x5FFF, 0xFFFF, 0xA21F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 
0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xA21F, 0x28FF, 0x07DF, 0x003F, 0x5FFF, 
0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 
0xFFFF, 0x0006, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0814, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0814, 0x003F, 0x5FFF, 0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 
0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xC91F, 0x28FF, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xA01F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xEA1F, 0x6CE4, 0xFFFF, 0x001F, 0x8AF2, 0x0865, 0x003F, 0x5FFF, 
0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 
0xFFFF, 0x0006, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x082C, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x082C, 0x003F, 0x5FFF, 0xFFFF, 0xA21F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 
0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xA21F, 0x28FF, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xA11F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xEA1F, 0x6CE4, 0xFFFF, 0x001F, 0x8AF2, 0x0865, 0x003F, 0x5FFF, 
0xFFFF, 0xC91F, 0x6CC7, 0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0xC91F, 0x28FF, 0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xA01F, 0x6CC2, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xEA1F, 0x6CE4, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xEB1F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0x0865, 0x003F, 0x5FFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xE01F, 0x6CCC, 0xFFFF, 0xD91F, 0x2AFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0x0865, 0x003F, 0x5FFF, 
0xFFFF, 0x0006, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0860, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0860, 0x003F, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0860, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 0x0865, 0x003F, 0x5FFF, 
0x0865, 0x003F, 0x5FFF, 0x0860, 0x003F, 0x5FFF, 0xFFFF, 0xC91F, 0x6CC7, 
0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xC91F, 0x28FF, 
0x0865, 0x003F, 0x5FFF, 0xFFFF, 0x0002, 0x5FFF, 0x01BA, 0x005F, 0x5FFF, 
0xFFFF, 0x0005, 0x5FFF, 0x01BA, 0x005F, 0x5FFF, 0xFFFF, 0xCD1F, 0x6CC7, 
0xFFFF, 0xFD1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xCD1F, 0x28FF, 
0xFFFF, 0xCD1F, 0x6CC7, 0xFFFF, 0xFE1F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0xCD1F, 0x28FF, 0x01BA, 0x003F, 0x5FFF, 0xFFFF, 0x000C, 0x5FFF, 
0x08B2, 0x00DF, 0x5FFF, 0xFFFF, 0xE01F, 0x6CF6, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xA31F, 0x2AFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xEA1F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0x0000, 0x5FFF, 0x08FF, 0x005F, 0x5FFF, 
0xFFFF, 0xC71F, 0x6CC7, 0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xEA1F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x08A0, 0x00DF, 0x5FFF, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xEA1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x08A0, 0x00DF, 0x5FFF, 
0xFFFF, 0xBA1F, 0x6CC7, 0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0x0007, 0x5FFF, 
0x08A0, 0x00DF, 0x5FFF, 0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE21F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x08AE, 0x005F, 0x5FFF, 0xFFFF, 0xBA1F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC00, 0xFFFF, 0xE11F, 0x6CE5, 0xFFFF, 0xBA1F, 0x28FF, 
0xFFFF, 0xC71F, 0x6CC7, 0xFFFF, 0x0007, 0xCCC0, 0x0895, 0x995F, 0x6CE3, 
0xFFFF, 0xE91F, 0x6CE4, 0xFFFF, 0xEB1F, 0x6CCC, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0x001F, 0x48C8, 0xFFFF, 0xC11F, 0x29FF, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xE41F, 0x6CCC, 0xFFFF, 0xF81F, 0x2AFF, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xE31F, 0x6CCC, 0xFFFF, 0xF81F, 0x2AFF, 0x08AE, 0x003F, 0x5FFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE21F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x08AE, 0x005F, 0x5FFF, 0xFFFF, 0xC71F, 0x6CC7, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0x991F, 0x6CE3, 0xFFFF, 0x9B1F, 0x6CCB, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF31F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xD81F, 0x6CC6, 0xFFFF, 0xBA1F, 0x28FF, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xF21F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 0x08FF, 0x003F, 0x5FFF, 
0xFFFF, 0xE11F, 0x6CF6, 0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xEE1F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x08D9, 0x005F, 0x5FFF, 0xFFFF, 0xB91F, 0x6CE2, 
0xFFFF, 0xA31F, 0x2AFF, 0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xEF1F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x08D1, 0x005F, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 
0xFFFF, 0xEA1F, 0x6CCC, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0x0006, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x08FC, 0x003F, 0x5FFF, 0x08FC, 0x003F, 0x5FFF, 
0x08FC, 0x003F, 0x5FFF, 0x08CA, 0x003F, 0x5FFF, 0x08FC, 0x003F, 0x5FFF, 
0x08FC, 0x003F, 0x5FFF, 0x08FC, 0x003F, 0x5FFF, 0x08CA, 0x003F, 0x5FFF, 
0xFFFF, 0xD41F, 0x6CC0, 0xFFFF, 0xA01F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xEA1F, 0x6CE4, 0xFFFF, 0x001F, 0x8AF2, 
0x08FC, 0x003F, 0x5FFF, 0xFFFF, 0xD41F, 0x6CC7, 0xFFFF, 0x001F, 0x5F27, 
0xFFFF, 0xE41F, 0x6C99, 0xFFFF, 0x001F, 0xCCE6, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0x0009, 0xCCE6, 0x08D6, 0x005F, 0x8A32, 0x08FC, 0x003F, 0x5F7F, 
0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xEB1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x08ED, 0x00DF, 0x5FFF, 0xFFFF, 0x0006, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 
0x08ED, 0x003F, 0x5FFF, 0x08ED, 0x003F, 0x5FFF, 0x08ED, 0x003F, 0x5FFF, 
0x08E7, 0x003F, 0x5FFF, 0x08ED, 0x003F, 0x5FFF, 0x08ED, 0x003F, 0x5FFF, 
0x08ED, 0x003F, 0x5FFF, 0x08E7, 0x003F, 0x5FFF, 0xFFFF, 0xD41F, 0x6CC0, 
0xFFFF, 0xA11F, 0x6CC2, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCCC0, 
0xFFFF, 0xEA1F, 0x6CE4, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xA41F, 0x6CC0, 
0xFFFF, 0xEA1F, 0x6CE3, 0xFFFF, 0xE307, 0x6CE3, 0x0900, 0x0047, 0x5FFF, 
0x0900, 0x005F, 0x5FFF, 0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xEF1F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x08FA, 0x005F, 0x5FFF, 0xFFFF, 0xFC1F, 0x6CE2, 
0xFFFF, 0xEB1F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x08FC, 0x005F, 0x5FFF, 
0xFFFF, 0xB91F, 0x6CE2, 0xFFFF, 0xA31F, 0x2AFF, 0xFFFF, 0xD91F, 0x6CE2, 
0xFFFF, 0xE21F, 0x6CCC, 0xFFFF, 0xD91F, 0x2AFF, 0x000C, 0x003F, 0x5FE9, 
0x000C, 0x003F, 0x5FFF, 0xFFFF, 0xE51F, 0x6CE3, 0xFFFF, 0xD307, 0x6CC7, 
0x000C, 0xE15F, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0x5F2C, 
0xFFFF, 0x001F, 0x5FF1, 0xFFFF, 0x001F, 0xCCC4, 0x000C, 0xD33F, 0x28FF, 
0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE01F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x0913, 0x005F, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE01F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0x0002, 0x5FFF, 0x0957, 0x00DF, 0x5FFF, 
0x0020, 0x002D, 0x5FF0, 0xFFFF, 0x0000, 0x5FFF, 0x0920, 0x00DF, 0x5FFF, 
0xFFFF, 0x0001, 0x5FFF, 0x09F8, 0x00DF, 0x5FFF, 0xFFFF, 0xB81F, 0x6CE2, 
0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xBC1F, 0x2AFF, 
0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xBF1F, 0x2AFF, 0xFFFF, 0xB81F, 0x6CE2, 
0xFFFF, 0xA31F, 0x2AFF, 0x0020, 0x002D, 0x5FF0, 0xFFFF, 0xF81F, 0x6CE2, 
0xFFFF, 0xE31F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x0915, 0x005F, 0x5FFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xE41F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 
0x092D, 0x00DF, 0x5FFF, 0xFFFF, 0xDA1F, 0x6CE2, 0xFFFF, 0xE91F, 0x6CCC, 
0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0xD81F, 0x6CC6, 0xFFFF, 0xBA1F, 0x28FF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF41F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xF81F, 0x6CE2, 0xFFFF, 0xF51F, 0x6CCB, 0xFFFF, 0xF81F, 0x2AFF, 
0xFFFF, 0xC71F, 0x6CC7, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xE71F, 0x6CE3, 
0xFFFF, 0xE407, 0x6CE3, 0x0939, 0xD9C7, 0x6CC0, 0x094B, 0x00DF, 0x5FF8, 
0x094B, 0xC3DF, 0x6CE3, 0xFFFF, 0xDA07, 0x6CC0, 0x093D, 0xC4DF, 0x6CE3, 
0x093F, 0x003F, 0x48C8, 0xFFFF, 0x0007, 0x5FFF, 0x094B, 0x00DF, 0x48C8, 
0xFFFF, 0xD31F, 0x6CC7, 0xFFFF, 0xE41F, 0x6CE2, 0xFFFF, 0x001F, 0x8A32, 
0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xD31F, 0x28FF, 
0xFFFF, 0xC71F, 0x6CC7, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xEC1F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x094B, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x5FF1, 
0xFFFF, 0xD91F, 0x6CC0, 0xFFFF, 0xC71F, 0x6CC7, 0x0008, 0x001F, 0x5CC0, 
0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0xD91F, 0x6C00, 0xFFFF, 0x001F, 0x89FF, 
0xFFFF, 0xDA1F, 0x6C00, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0xCCE2, 
0xFFFF, 0x0007, 0x5FFF, 0x0915, 0xB85F, 0x6CC0, 0x0915, 0xAE3F, 0x29FF, 
0xFFFF, 0xF905, 0x6CC0, 0x0912, 0xE75F, 0x6CE3, 0xFFFF, 0x0007, 0x5FFF, 
0x0912, 0xF7DF, 0x6CE3, 0xFFFF, 0xD71F, 0x6CC7, 0xFFFF, 0x001F, 0xCC00, 
0xFFFF, 0xE41F, 0x6CE3, 0xFFFF, 0xD907, 0x6CE2, 0x0963, 0xE1DF, 0x6CCB, 
0xFFFF, 0x000F, 0x5FFF, 0x09DA, 0x005F, 0x5FFF, 0x09D2, 0x003F, 0x5FFD, 
0xFFFF, 0xE507, 0x6CE3, 0x0966, 0x00C7, 0x5FFF, 0x09DA, 0x00DF, 0x5FFF, 
0xFFFF, 0x0010, 0x49FF, 0xFFFF, 0x00FF, 0x5FFF, 0x09DA, 0x003F, 0x5FFF, 
0x09DA, 0x003F, 0x5FFF, 0x0978, 0x003F, 0x5FFF, 0x09DA, 0x003F, 0x5FFF, 
0x09DA, 0x003F, 0x5FFF, 0x097D, 0x003F, 0x5F3F, 0x0978, 0x003F, 0x5FFF, 
0x097D, 0x003F, 0x5F3F, 0x09DA, 0x003F, 0x5FFF, 0x09DA, 0x003F, 0x5FFF, 
0x0978, 0x003F, 0x5FFF, 0x09DA, 0x003F, 0x5FFF, 0x09DA, 0x003F, 0x5FFF, 
0x097D, 0x003F, 0x5F3F, 0x0978, 0x003F, 0x5FFF, 0x097D, 0x003F, 0x5F3F, 
0xFFFF, 0xB21F, 0x28FF, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xB31F, 0x29FF, 
0x0002, 0x001F, 0x5CC0, 0x0982, 0x003F, 0x48C5, 0xFFFF, 0xB21F, 0x28FF, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xB31F, 0x29FF, 0x0015, 0x001F, 0x5CC0, 
0x0982, 0x003F, 0x48C5, 0xFFFF, 0x001F, 0xCC00, 0xFFFF, 0xFE1F, 0x28FF, 
0xFFFF, 0xCC1F, 0x6CC6, 0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0x001F, 0xCCE2, 
0xFFFF, 0xFE1F, 0x6CC7, 0xFFFF, 0x001F, 0xCC0D, 0xFFFF, 0x001F, 0xCC0B, 
0xFFFF, 0x0007, 0x5F3F, 0x0997, 0xFE5F, 0x28FF, 0xFFFF, 0x001F, 0xCCC4, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0xFE07, 0x6CC7, 
0x0997, 0x005F, 0x8AF2, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0xCC22, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xB31F, 0x6CE2, 0xFFFF, 0xE01F, 0x6CCC, 
0xFFFF, 0xB31F, 0x2AFF, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x001F, 0xCC00, 
0xFFFF, 0xFE1F, 0x28FF, 0xFFFF, 0xCC1F, 0x6CC6, 0xFFFF, 0x001F, 0x48C5, 
0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xFE1F, 0x6CC7, 0xFFFF, 0x001F, 0xCC0D, 
0xFFFF, 0x001F, 0xCC0B, 0xFFFF, 0x0007, 0x5F3F, 0x09AD, 0xFE5F, 0x28FF, 
0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0x48E2, 
0xFFFF, 0xFE07, 0x6CC7, 0x09AD, 0x005F, 0x8AF2, 0xFFFF, 0x001F, 0x5F7F, 
0xFFFF, 0x001F, 0xCC22, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xB31F, 0x6CE2, 
0xFFFF, 0xE11F, 0x6CCC, 0xFFFF, 0xB31F, 0x2AFF, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x001F, 0xCC00, 0xFFFF, 0xFE1F, 0x28FF, 0xFFFF, 0xCC1F, 0x6CC6, 
0xFFFF, 0x001F, 0x48C5, 0xFFFF, 0x001F, 0xCCE2, 0xFFFF, 0xFE1F, 0x6CC7, 
0xFFFF, 0x001F, 0xCC0D, 0xFFFF, 0x001F, 0xCC0B, 0xFFFF, 0x0007, 0x5F3F, 
0x09C3, 0xFE5F, 0x28FF, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0x001F, 0x5F7F, 
0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0xFE07, 0x6CC7, 0x09C3, 0x005F, 0x8AF2, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0xCC22, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0xB31F, 0x6CE2, 0xFFFF, 0xE21F, 0x6CCC, 0xFFFF, 0xB31F, 0x2AFF, 
0xFFFF, 0xB31F, 0x6CE2, 0xFFFF, 0x0014, 0x5FFF, 0xFFFF, 0xB2FF, 0x6CC7, 
0x09DA, 0x003F, 0x8AF2, 0x09D0, 0x003F, 0x5FFF, 0x09CF, 0xF03F, 0x6CCB, 
0x09CF, 0xF13F, 0x6CCB, 0x09CF, 0xF23F, 0x6CCB, 0x09CE, 0xF03F, 0x6CCB, 
0x09CE, 0xF13F, 0x6CCB, 0x09DA, 0x003F, 0x5FFF, 0xFFFF, 0xF21F, 0x6CCB, 
0x09DA, 0x003F, 0x8AF2, 0xFFF0, 0x001F, 0x5CCB, 0xFFFF, 0x001F, 0x8AF2, 
0xFFFF, 0xD71F, 0x6CC7, 0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xE01F, 0x6CE5, 
0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xE71F, 0x6CE3, 0xFFFF, 0xE507, 0x6CE2, 
0x09E1, 0xBBDF, 0x2AFF, 0x09E1, 0x003F, 0x5FFE, 0xFFFF, 0xB81F, 0x6CE2, 
0xFFFF, 0xBB1F, 0x2AFF, 0xFFFF, 0xD71F, 0x6CC7, 0xFFFF, 0x001F, 0xCCE2, 
0xFFFF, 0xE01F, 0x6CCB, 0xFFFF, 0x0007, 0x5FFF, 0x09F1, 0x00DF, 0x5FFF, 
0xFFFF, 0xCC1F, 0x6CC6, 0xFFFF, 0xD91F, 0x6C00, 0xFFFF, 0x001F, 0xCCE3, 
0xFFFF, 0xDA07, 0x6C00, 0x09E7, 0x00DF, 0xCCE3, 0x09E9, 0xD33F, 0x6CC7, 
0xFFFF, 0x0007, 0x5FFF, 0x09F1, 0xD3DF, 0x6CC7, 0xFFFF, 0xE31F, 0x6CE2, 
0xFFFF, 0xBB1F, 0x6CCC, 0xFFFF, 0x001F, 0x8A32, 0xFFFF, 0xCC1F, 0x6CC0, 
0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xD31F, 0x28FF, 
0xFFFF, 0x001F, 0x5FF1, 0xFFFF, 0xCC1F, 0x6CC6, 0xFFFF, 0x001F, 0xCC00, 
0xFFFF, 0xCC1F, 0x293F, 0xFFFF, 0xD91F, 0x6C00, 0xFFFF, 0x001F, 0x893F, 
0xFFFF, 0xDA1F, 0x6CC0, 0x0912, 0x003F, 0x89FF, 0xFFFF, 0xCA1F, 0x6CE2, 
0xFFFF, 0xFF1F, 0x2AFF, 0xFFFF, 0xCA1F, 0x6CC6, 0xFFFF, 0x001F, 0xCC22, 
0xFFFF, 0xCA1F, 0x2A3F, 0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xEB1F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x0A24, 0x00DF, 0x5FFF, 0xFFFF, 0x0001, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x0A1F, 0x003F, 0x5FFF, 0x0A1F, 0x003F, 0x5FFF, 
0x0A1F, 0x003F, 0x5FFF, 0x0A0B, 0x003F, 0x5FFF, 0x0A1F, 0x003F, 0x5FFF, 
0x0A1F, 0x003F, 0x5FFF, 0x0A1F, 0x003F, 0x5FFF, 0x0A0B, 0x003F, 0x5FFF, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xD91F, 0x6C23, 0xFFFF, 0x0007, 0xCCC0, 
0x0A10, 0xDADF, 0x6C23, 0x0A12, 0xD93F, 0x6CC0, 0xFFFF, 0x0007, 0x5FFF, 
0x0A1E, 0xD9DF, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0xDA1F, 0x6CC0, 
0xFFFF, 0xE81F, 0x6CE4, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xD31F, 0x6CC7, 
0xFFFF, 0xE21F, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0xFF1F, 0x6CC0, 
0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xD31F, 0x28FF, 
0xFFFF, 0x001F, 0x5FF1, 0xFFFF, 0x001F, 0x5FFF, 0xFFFF, 0xCB1F, 0x6CE2, 
0xFFFF, 0xFF1F, 0x2AFF, 0xFFFF, 0xCB1F, 0x6CC6, 0xFFFF, 0x001F, 0xCC22, 
0xFFFF, 0xCB1F, 0x2A3F, 0xFFFF, 0xFC1F, 0x6CE2, 0xFFFF, 0xEF1F, 0x6CCB, 
0xFFFF, 0x0007, 0x5FFF, 0x0A32, 0x005F, 0x5FFF, 0xFFFF, 0x0006, 0x5FFF, 
0xFFFF, 0x00FF, 0x5FFF, 0x0917, 0x003F, 0x5FFF, 0x0917, 0x003F, 0x5FFF, 
0x0917, 0x003F, 0x5FFF, 0x0A32, 0x003F, 0x5FFF, 0x0917, 0x003F, 0x5FFF, 
0x0917, 0x003F, 0x5FFF, 0x0917, 0x003F, 0x5FFF, 0x0A32, 0x003F, 0x5FFF, 
0xFFFF, 0x001F, 0xCCC0, 0xFFFF, 0xD91F, 0x6C23, 0xFFFF, 0x0007, 0xCCC0, 
0x0A37, 0xDADF, 0x6C23, 0x0A39, 0xD93F, 0x6CC0, 0xFFFF, 0x0007, 0x5FFF, 
0x0A45, 0xD9DF, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0xDA1F, 0x6CC0, 
0xFFFF, 0xE81F, 0x6CE4, 0xFFFF, 0x001F, 0x8AF2, 0xFFFF, 0xD31F, 0x6CC7, 
0xFFFF, 0xE21F, 0x6CC0, 0xFFFF, 0x001F, 0x893F, 0xFFFF, 0xFF1F, 0x6CC0, 
0xFFFF, 0x001F, 0x893F, 0xFFFF, 0x001F, 0xCCC4, 0xFFFF, 0xD31F, 0x28FF, 
0xFFFF, 0x001F, 0x5FF1, 0xFFFF, 0x001F, 0x5FFF, 0x0917, 0x003F, 0x5FFF, 
0xFFFF, 0x000B, 0x5FFF, 0xFFFF, 0x00FF, 0x5FFF, 0x000C, 0x003F, 0x5FFF, 
0x000C, 0x003F, 0x5FFF, 0x000C, 0x003F, 0x5FFF, 0x0A51, 0x003F, 0x5FFF, 
0x000C, 0x003F, 0x5FFF, 0x000C, 0x003F, 0x5FFF, 0x000C, 0x003F, 0x5FFF, 
0x0A51, 0x003F, 0x5FFF, 0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE21F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x0A5E, 0x005F, 0x5FFF, 0x0000, 0x001F, 0x5CE2, 
0xFFFF, 0xCE1F, 0x2AFF, 0xFFFF, 0x921F, 0x6CF5, 0xFFFF, 0x971F, 0x29FF, 
0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE21F, 0x6CE4, 0xFFFF, 0x001F, 0x4AF9, 
0xFFFF, 0xB81F, 0x6CE2, 0xFFFF, 0xDA1F, 0x2AFF, 0xFFFF, 0x971F, 0x6CC7, 
0xFFFF, 0xCE1F, 0x6CE2, 0xFFFF, 0x0007, 0x5FFF, 0x0B15, 0x005F, 0x4AC0, 
0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE51F, 0x6CE3, 0xFFFF, 0x0007, 0x5FFF, 
0x0A69, 0x005F, 0xCCC0, 0xFFFF, 0xEC1F, 0x6CE3, 0xFFFF, 0xED07, 0x6CE3, 
0x0A6A, 0x00C7, 0x5FFF, 0x000C, 0xB83F, 0x6CF9, 0x0ACB, 0xEEDF, 0x6CE3, 
0xFFFF, 0x971F, 0x6CC7, 0xFFFF, 0x911F, 0x6C22, 0xFFFF, 0x001F, 0x48C8, 
0xFFFF, 0x0008, 0x5FFF, 0x0A72, 0x005F, 0x5FFF, 0xFFFF, 0x901F, 0x6CF5, 
0x0A73, 0x973F, 0x29FF, 0xFFFF, 0x971F, 0x28FF, 0xFFFF, 0x971F, 0x6CC8, 
0xFFFF, 0x931F, 0x6CE2, 0xFFFF, 0x9208, 0x29FF, 0x0A7A, 0x005F, 0x5FFF, 
0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE41F, 0x6CE4, 0xFFFF, 0x001F, 0x4AF9, 
0xFFFF, 0x961F, 0x6CC7, 0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0x48E2, 
0xFFFF, 0x0007, 0x5FFF, 0x0A88, 0x005F, 0x5FFF, 0xFFFF, 0x951F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x951F, 0x28FF, 0xFFFF, 0x001F, 0x50C0, 
0xFFFF, 0xE11F, 0x6CE3, 0xFFFF, 0x0007, 0x5FFF, 0x0A87, 0x00DF, 0x5FFF, 
0xFFFF, 0x001F, 0x5FF1, 0xFFFF, 0x941F, 0x6CE2, 0xFFFF, 0x961F, 0x2AFF, 
0xFFFF, 0x971F, 0x6CC7, 0xFFFF, 0x001F, 0xCCCE, 0xFFFF, 0x971F, 0x6CC7, 
0xFFFF, 0x911F, 0x6C22, 0xFFFF, 0x001F, 0x48C8, 0xFFFF, 0x0008, 0x5FFF, 
0x0A92, 0x005F, 0x5FFF, 0xFFFF, 0x901F, 0x6CF5, 0x0A93, 0x973F, 0x29FF, 
0xFFFF, 0x971F, 0x28FF, 0xFFFF, 0x971F, 0x6CC8, 0xFFFF, 0x931F, 0x6CE2, 
0xFFFF, 0x9208, 0x29FF, 0x0A9A, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x50C0, 
0xFFFF, 0xE41F, 0x6CE4, 0xFFFF, 0x001F, 0x4AF9, 0xFFFF, 0x961F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0x0007, 0x5FFF, 
0x0AA8, 0x005F, 0x5FFF, 0xFFFF, 0x951F, 0x6CC7, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x951F, 0x28FF, 0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE11F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x0AA7, 0x00DF, 0x5FFF, 0xFFFF, 0x001F, 0x5FF1, 
0xFFFF, 0x941F, 0x6CE2, 0xFFFF, 0x961F, 0x2AFF, 0xFFFF, 0x971F, 0x6CC7, 
0xFFFF, 0x001F, 0xCCCF, 0xFFFF, 0x971F, 0x6CC7, 0xFFFF, 0x911F, 0x6C22, 
0xFFFF, 0x001F, 0x48C8, 0xFFFF, 0x0008, 0x5FFF, 0x0AB2, 0x005F, 0x5FFF, 
0xFFFF, 0x901F, 0x6CF5, 0x0AB3, 0x973F, 0x29FF, 0xFFFF, 0x971F, 0x28FF, 
0xFFFF, 0x971F, 0x6CC8, 0xFFFF, 0x931F, 0x6CE2, 0xFFFF, 0x9208, 0x29FF, 
0x0ABA, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE41F, 0x6CE4, 
0xFFFF, 0x001F, 0x4AF9, 0xFFFF, 0x961F, 0x6CC7, 0xFFFF, 0x001F, 0x5F7F, 
0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0x0007, 0x5FFF, 0x0AC8, 0x005F, 0x5FFF, 
0xFFFF, 0x951F, 0x6CC7, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x951F, 0x28FF, 
0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE11F, 0x6CE3, 0xFFFF, 0x0007, 0x5FFF, 
0x0AC7, 0x00DF, 0x5FFF, 0xFFFF, 0x001F, 0x5FF1, 0xFFFF, 0x941F, 0x6CE2, 
0xFFFF, 0x961F, 0x2AFF, 0xFFFF, 0x971F, 0x6CC7, 0x000C, 0x003F, 0x5FFF, 
0xFFFF, 0x0007, 0x5FFF, 0x0AD0, 0xFB5F, 0x29FF, 0xFFFF, 0x001F, 0x50C0, 
0xFFFF, 0xE31F, 0x6CE4, 0x0AAB, 0x003F, 0x4AF9, 0xFFFF, 0xE61F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x0AF4, 0x00DF, 0x5FFF, 0xFFFF, 0x971F, 0x6CC7, 
0xFFFF, 0x911F, 0x6C22, 0xFFFF, 0x001F, 0x48C8, 0xFFFF, 0x0008, 0x5FFF, 
0x0ADA, 0x005F, 0x5FFF, 0xFFFF, 0x901F, 0x6CF5, 0x0ADB, 0x973F, 0x29FF, 
0xFFFF, 0x971F, 0x28FF, 0xFFFF, 0x971F, 0x6CC8, 0xFFFF, 0x931F, 0x6CE2, 
0xFFFF, 0x9208, 0x29FF, 0x0AE2, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x50C0, 
0xFFFF, 0xE41F, 0x6CE4, 0xFFFF, 0x001F, 0x4AF9, 0xFFFF, 0x961F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0x0007, 0x5FFF, 
0x0AF0, 0x005F, 0x5FFF, 0xFFFF, 0x951F, 0x6CC7, 0xFFFF, 0x001F, 0x5F3F, 
0xFFFF, 0x951F, 0x28FF, 0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE11F, 0x6CE3, 
0xFFFF, 0x0007, 0x5FFF, 0x0AEF, 0x00DF, 0x5FFF, 0xFFFF, 0x001F, 0x5FF1, 
0xFFFF, 0x941F, 0x6CE2, 0xFFFF, 0x961F, 0x2AFF, 0xFFFF, 0x971F, 0x6CC7, 
0xFFFF, 0x001F, 0xCCDD, 0x0AAB, 0xFB3F, 0x6CD2, 0xFFFF, 0xBE1F, 0x6CE3, 
0xFFFF, 0xCE1F, 0x2AFF, 0xFFFF, 0x971F, 0x6CC7, 0xFFFF, 0x911F, 0x6C22, 
0xFFFF, 0x001F, 0x48C8, 0xFFFF, 0x0008, 0x5FFF, 0x0AFD, 0x005F, 0x5FFF, 
0xFFFF, 0x901F, 0x6CF5, 0x0AFE, 0x973F, 0x29FF, 0xFFFF, 0x971F, 0x28FF, 
0xFFFF, 0x971F, 0x6CC8, 0xFFFF, 0x931F, 0x6CE2, 0xFFFF, 0x9208, 0x29FF, 
0x0B05, 0x005F, 0x5FFF, 0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE41F, 0x6CE4, 
0xFFFF, 0x001F, 0x4AF9, 0xFFFF, 0x961F, 0x6CC7, 0xFFFF, 0x001F, 0x5F7F, 
0xFFFF, 0x001F, 0x48E2, 0xFFFF, 0x0007, 0x5FFF, 0x0B13, 0x005F, 0x5FFF, 
0xFFFF, 0x951F, 0x6CC7, 0xFFFF, 0x001F, 0x5F3F, 0xFFFF, 0x951F, 0x28FF, 
0xFFFF, 0x001F, 0x50C0, 0xFFFF, 0xE11F, 0x6CE3, 0xFFFF, 0x0007, 0x5FFF, 
0x0B12, 0x00DF, 0x5FFF, 0xFFFF, 0x001F, 0x5FF1, 0xFFFF, 0x941F, 0x6CE2, 
0xFFFF, 0x961F, 0x2AFF, 0xFFFF, 0x971F, 0x6CC7, 0xFFFF, 0xCE1F, 0x6CC7, 
0xFFFF, 0x001F, 0x5F7F, 0xFFFF, 0xCE1F, 0x28FF, 0xFFFF, 0x971F, 0x6CC7, 
0xFFFF, 0x001F, 0xCCDD, 0x0AAB, 0xFB3F, 0x6CD2, 0x0B20, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0xFFFF, 0xDB1F, 0x6CE2, 0xFFFF, 0xE81F, 0x6CCC, 
0xFFFF, 0xDB1F, 0x2AFF, 0x0006, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 
0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF, 0x0B20, 0x003F, 0x5FFF,

